@@ -72,7 +72,7 @@ cpl_table *muse_basicproc_get_illum(muse_imagelist *, cpl_table *, cpl_table *,
 cpl_error_code muse_basicproc_apply_illum(muse_pixtable *, cpl_table *);
 cpl_error_code muse_basicproc_apply_twilight(muse_pixtable *, muse_datacube *);
 muse_imagelist *muse_basicproc_combine_images_lampwise(muse_processing *, unsigned char, muse_basicproc_params *, cpl_frameset ***);
-cpl_error_code muse_basicproc_shift_pixtable(muse_pixtable *, cpl_array *, double, double);
+cpl_error_code muse_basicproc_shift_pixtable(muse_pixtable *, cpl_array *, double, double, float, float, unsigned char);
 cpl_error_code muse_basicproc_stats_append_header(cpl_image *, cpl_propertylist *, const char *, unsigned);
 cpl_error_code muse_basicproc_stats_append_header_window(cpl_image *, cpl_propertylist *, const char *, unsigned, int, int, int, int);
 
