@@ -200,7 +200,7 @@ muse_cplimage_concat_x(const cpl_image *aImage1, const cpl_image *aImage2)
  */
 /*----------------------------------------------------------------------------*/
 cpl_image *
-muse_cplimage_filter_median_subtract(cpl_image *aImage, 
+muse_cplimage_filter_median_subtract(cpl_image *aImage,
                                      unsigned int aNX, unsigned int aNY)
 {
   cpl_ensure(aImage, CPL_ERROR_NULL_INPUT, NULL);
@@ -343,7 +343,7 @@ muse_cplimage_slope_window(const cpl_image *aImage, const cpl_size *aWindow)
 
 */
 /*----------------------------------------------------------------------------*/
-double 
+double
 muse_cplimage_get_percentile(const cpl_image *aImage, double aFraction) {
   cpl_ensure(aImage != NULL, CPL_ERROR_NULL_INPUT, 0.0);
 
@@ -973,7 +973,7 @@ muse_cpltable_load(const char *aFile, const char *aExtension,
    @param aTable Table to save.
    @param aFile File name
    @param aExtension Extension name
-   @param aDefinition Optional table definition. If not NULL, table 
+   @param aDefinition Optional table definition. If not NULL, table
           will be checked against this definition before saving.
    @retval CPL_ERROR_NONE Success
    @cpl_ensure_code{aTable != NULL, CPL_ERROR_NULL_INPUT}
@@ -986,12 +986,12 @@ muse_cpltable_load(const char *aFile, const char *aExtension,
  */
 /*----------------------------------------------------------------------------*/
 cpl_error_code
-muse_cpltable_append_file(const cpl_table *aTable, const char *aFile, 
-                          const char *aExtension, 
+muse_cpltable_append_file(const cpl_table *aTable, const char *aFile,
+                          const char *aExtension,
                           const muse_cpltable_def aDefinition[]) {
-  cpl_ensure_code(aTable != NULL, CPL_ERROR_NULL_INPUT); 
-  cpl_ensure_code(aFile != NULL, CPL_ERROR_NULL_INPUT); 
-  cpl_ensure_code(aExtension != NULL, CPL_ERROR_NULL_INPUT); 
+  cpl_ensure_code(aTable != NULL, CPL_ERROR_NULL_INPUT);
+  cpl_ensure_code(aFile != NULL, CPL_ERROR_NULL_INPUT);
+  cpl_ensure_code(aExtension != NULL, CPL_ERROR_NULL_INPUT);
   cpl_error_code r = muse_cpltable_check(aTable, aDefinition);
   if (r != CPL_ERROR_NONE) {
     cpl_msg_error(__func__, " %s['%s'] Table format error", aFile, aExtension);
@@ -1003,7 +1003,7 @@ muse_cpltable_append_file(const cpl_table *aTable, const char *aFile,
   r = cpl_table_save(aTable, NULL, props, aFile, CPL_IO_EXTEND);
   cpl_propertylist_delete(props);
   if (r != CPL_ERROR_NONE) {
-    cpl_msg_error(__func__, "%s[%s]: %s", aFile, aExtension, 
+    cpl_msg_error(__func__, "%s[%s]: %s", aFile, aExtension,
                   cpl_error_get_message());
   }
   return r;
@@ -1459,6 +1459,24 @@ static int cmp_int_desc(const void *p1, const void *p2) {
   return (*(const int *)p2 - *(const int *)p1);
 }
 
+/** @private */
+static int cmp_long_asc(const void *p1, const void *p2) {
+  return (*(const long *)p1 - *(const long *)p2);
+}
+/** @private */
+static int cmp_long_desc(const void *p1, const void *p2) {
+  return (*(const long *)p2 - *(const long *)p1);
+}
+
+/** @private */
+static int cmp_string_asc(const void *p1, const void *p2) {
+  return strcmp(*(const char **)p1, *(const char **)p2);
+}
+/** @private */
+static int cmp_string_desc(const void *p1, const void *p2) {
+  return strcmp(*(const char **)p2, *(const char **)p1);
+}
+
 /*----------------------------------------------------------------------------*/
 /**
    @brief Sort float, int or double array by quicksort.
@@ -1489,6 +1507,14 @@ muse_cplarray_sort(cpl_array *aArray, cpl_boolean aOrder)
     int *d = cpl_array_get_data_int(aArray);
     qsort(d, n, sizeof(int), (aOrder)?cmp_int_asc:cmp_int_desc);
     return CPL_ERROR_NONE;
+  } else if (cpl_array_get_type(aArray) == CPL_TYPE_LONG) {
+    long *d = cpl_array_get_data_long(aArray);
+    qsort(d, n, sizeof(long), (aOrder)?cmp_long_asc:cmp_long_desc);
+    return CPL_ERROR_NONE;
+  } else if (cpl_array_get_type(aArray) == CPL_TYPE_STRING) {
+    char **d = cpl_array_get_data_string(aArray);
+    qsort(d, n, sizeof(char *), (aOrder)?cmp_string_asc:cmp_string_desc);
+    return CPL_ERROR_NONE;
   } else {
     return CPL_ERROR_ILLEGAL_INPUT;
   }
@@ -1960,7 +1986,7 @@ muse_cplarray_interpolate_table_linear(const cpl_array *aTargetAbscissa,
                                        const char *aSrcAbscissa,
                                        const char *aSrcOrdinate)
 {
-  cpl_array *sabs = muse_cpltable_extract_column((cpl_table *)aSrcTable, 
+  cpl_array *sabs = muse_cpltable_extract_column((cpl_table *)aSrcTable,
                                                   aSrcAbscissa);
   cpl_array *sord = muse_cpltable_extract_column((cpl_table *)aSrcTable,
                                                  aSrcOrdinate);
@@ -2240,7 +2266,7 @@ muse_cplparameterlist_duplicate(const cpl_parameterlist *aPList)
   CPL_TYPE_LONG_LONG, this function makes it easier to update properties that
   can be any of those three. The user should take care that the value cannot
   overflow the actual variable type.
- 
+
   @error{set and return CPL_ERROR_NULL_INPUT, aHeader and/or aKeyword are NULL}
   @error{set and return CPL_ERROR_DATA_NOT_FOUND,
          no property named aKeyword was found}
