@@ -189,7 +189,8 @@ muse_euro3dcube_collapse(muse_euro3dcube *aEuro3D, cpl_table *aFilter)
   double crvals = cpl_propertylist_get_double(aEuro3D->hdata, "CRVALS"),
          cdelts = cpl_propertylist_get_double(aEuro3D->hdata, "CDELTS");
   const char *ctypes = cpl_propertylist_get_string(aEuro3D->hdata, "CTYPES");
-  cpl_boolean loglambda = ctypes && !strncmp(ctypes, "AWAV-LOG", 9);
+  cpl_boolean loglambda = ctypes && (!strncmp(ctypes, "AWAV-LOG", 9) ||
+                                     !strncmp(ctypes, "WAVE-LOG", 9));
   cpl_msg_debug(__func__, "spectral WCS: %f / %f %s", crvals, cdelts,
                 loglambda ? "log" : "linear");
   int l1 = 0, l2 = nz; /* loop boundaries for filter operation */
@@ -318,6 +319,8 @@ muse_euro3dcube_collapse(muse_euro3dcube *aEuro3D, cpl_table *aFilter)
 
   @error{set CPL_ERROR_NULL_INPUT\, return NULL,
          the input cube\, its data\, or its header is NULL}
+  @error{set CPL_ERROR_INCOMPATIBLE_INPUT\, return NULL,
+         the input cube components\, if they exist\, are not of the expected type (float and int)}
   @error{integrate over the whole wavelength range, filter table is NULL}
  */
 /*---------------------------------------------------------------------------*/
@@ -325,6 +328,16 @@ muse_image *
 muse_datacube_collapse(muse_datacube *aCube, cpl_table *aFilter)
 {
   cpl_ensure(aCube && aCube->data && aCube->header, CPL_ERROR_NULL_INPUT, NULL);
+  cpl_ensure(cpl_image_get_type(cpl_imagelist_get(aCube->data, 0)) == CPL_TYPE_FLOAT,
+             CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+  if (aCube->dq) {
+    cpl_ensure(cpl_image_get_type(cpl_imagelist_get(aCube->dq, 0)) == CPL_TYPE_INT,
+               CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+  }
+  if (aCube->stat) {
+    cpl_ensure(cpl_image_get_type(cpl_imagelist_get(aCube->stat, 0)) == CPL_TYPE_FLOAT,
+               CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+  }
 
   /* find in/output dimensions */
   int nx = cpl_image_get_size_x(cpl_imagelist_get(aCube->data, 0)),
@@ -335,7 +348,8 @@ muse_datacube_collapse(muse_datacube *aCube, cpl_table *aFilter)
          crval3 = muse_pfits_get_crval(aCube->header, 3),
          cd33 = muse_pfits_get_cd(aCube->header, 3, 3);
   const char *ctype3 = muse_pfits_get_ctype(aCube->header, 3);
-  cpl_boolean loglambda = ctype3 && !strncmp(ctype3, "AWAV-LOG", 9);
+  cpl_boolean loglambda = ctype3 && (!strncmp(ctype3, "AWAV-LOG", 9) ||
+                                     !strncmp(ctype3, "WAVE-LOG", 9));
   int l1 = 0, l2 = nz; /* loop boundaries for filter operation */
   double *fdata = muse_datacube_collapse_filter_buffer(aFilter, crval3, crpix3,
                                                        cd33, loglambda, &l1, &l2);
@@ -794,6 +808,9 @@ muse_datacube_load_header(const char *aFilename)
             primary HDU of the file and the WCS keywords as well as BUNIT of
             the DATA extension.
   @remark   Both DQ and STAT components of the file are optional.
+  @remark   The types of the three primary extensions (DATA, DQ, and STAT) are
+            are casted to float, int, and float, respectively, during loading.
+            The types of the reconstructed images are taken from the file.
   @warning  This function ignores the ESO-format headers like HDUCLASS.
   @note     When loading extra reconstructed images from the cube file, this
             function assumes that DQ and STAT extensions belonging to a
@@ -827,15 +844,15 @@ muse_datacube_load(const char *aFilename)
     return NULL;
   }
   int ext = cpl_fits_find_extension(aFilename, "DATA");
-  cube->data = cpl_imagelist_load(aFilename, CPL_TYPE_UNSPECIFIED, ext);
+  cube->data = cpl_imagelist_load(aFilename, CPL_TYPE_FLOAT, ext);
   /* DQ is usually not written to disk, but see if it's there and load it, if so */
   ext = cpl_fits_find_extension(aFilename, "DQ");
   if (ext > 0) {
-    cube->stat = cpl_imagelist_load(aFilename, CPL_TYPE_UNSPECIFIED, ext);
+    cube->stat = cpl_imagelist_load(aFilename, CPL_TYPE_INT, ext);
   }
   ext = cpl_fits_find_extension(aFilename, "STAT");
   if (ext > 0) {
-    cube->stat = cpl_imagelist_load(aFilename, CPL_TYPE_UNSPECIFIED, ext);
+    cube->stat = cpl_imagelist_load(aFilename, CPL_TYPE_FLOAT, ext);
   }
   int next = cpl_fits_count_extensions(aFilename);
   while (++ext <= next) {
@@ -887,6 +904,7 @@ muse_datacube_load(const char *aFilename)
 
   @note The reconstructed images present in aCube are most likely meaningless
         after concatenating. Hence, they are removed by this function!
+  @note Both cubes must be of the same spectral type (AWAV or WAVE).
   @note A logarithmic dispersion axis is currently not supported.
 
   @error{return and set CPL_ERROR_NULL_INPUT, aCube and/or aAppend are NULL}
@@ -919,7 +937,8 @@ muse_datacube_concat(muse_datacube *aCube, const muse_datacube *aAppend)
   const char *ctype1 = muse_pfits_get_ctype(aCube->header, 3),
              *ctype2 = muse_pfits_get_ctype(aCube->header, 3);
   cpl_ensure_code(ctype1 && ctype2, CPL_ERROR_UNSUPPORTED_MODE);
-  cpl_ensure_code(!strncmp(ctype1, "AWAV", 5) && !strncmp(ctype2, "AWAV", 5),
+  cpl_ensure_code((!strncmp(ctype1, "AWAV", 5) && !strncmp(ctype2, "AWAV", 5)) ||
+                  (!strncmp(ctype1, "WAVE", 5) && !strncmp(ctype2, "WAVE", 5)),
                   CPL_ERROR_UNSUPPORTED_MODE);
   /* compute wavelengths of last plane of first cube and first plane *
    * of the cube to append, to check that they are adjacent          */
@@ -931,7 +950,7 @@ muse_datacube_concat(muse_datacube *aCube, const muse_datacube *aAppend)
          cd2 = muse_pfits_get_cd(aAppend->header, 3, 3),
          lbda1 = ((ndata - 1) + 1. - pix1) * cd1 + val1,
          lbda2 = (0 + 1. - pix2) * cd2 + val2;
-  /* AWAV-LOG axes need more complex handling, so exclude them above */
+  /* AWAV-LOG and WAVE-LOG axes need more complex handling, so exclude them above */
   cpl_msg_debug(__func__, "lambdas: %f %f (%f %f)", lbda1, lbda2, cd1, cd2);
   cpl_ensure_code(fabs(cd1 - cd2) < DBL_EPSILON &&
                   fabs(lbda2 - cd2 - lbda1) < DBL_EPSILON,
