@@ -90,6 +90,9 @@
 #define MUSE_TAG_OFFSET_LIST      "OFFSET_LIST"
 /* tags used by the muse_qi_mask recipe */
 #define MUSE_TAG_MASK_IMAGE  "MASK_IMAGE"
+/* tags from detmon used by the muse_lingain recipe */
+#define MUSE_TAG_LINEARITY_BIAS "DETMON_LAMP_OFF"
+#define MUSE_TAG_LINEARITY_FLAT "DETMON_LAMP_ON"
 
 /* Reasons to exclude frames from a framelist */
 #define MUSE_EXCLUDE_OK           0 /* frame not excluded */
@@ -165,6 +168,17 @@
  * name in the collapsed images (IMAGE_FOV) */
 #define MUSE_HDR_FILTER "ESO DRS MUSE FILTER NAME"
 
+/* informational keywords used when computing the WCS solution */
+#define MUSE_HDR_WCS_DETSIGMA       "ESO DRS MUSE WCS DETSIGMA"
+#define MUSE_HDR_WCS_DETSIGMA_C     "Final detsigma level used"
+#define MUSE_HDR_WCS_DETSIGMA_C_ONE "detsigma used"
+#define MUSE_HDR_WCS_RADIUS         "ESO DRS MUSE WCS RADIUS"
+#define MUSE_HDR_WCS_RADIUS_C       "[pix] final ppm radius used"
+#define MUSE_HDR_WCS_ACCURACY       "ESO DRS MUSE WCS ACCURACY"
+#define MUSE_HDR_WCS_ACCURACY_C     "[pix] final ppm accuracy used"
+#define MUSE_HDR_WCS_FACCURACY      "ESO DRS MUSE WCS FACCURACY"
+#define MUSE_HDR_WCS_FACCURACY_C    "final fractional accuracy used"
+
 /* Bias QC headers */
 #define QC_BIAS_PREFIXi         "ESO QC BIAS INPUT%d"
 #define QC_BIAS_MASTER_PREFIX   "ESO QC BIAS MASTER"
@@ -247,11 +261,16 @@
 #define QC_GEO_EXPk_MEAN    QC_GEO_PREFIX"EXP%d FWHM MEAN"
 #define QC_GEO_EXPk_MEDIAN  QC_GEO_PREFIX"EXP%d FWHM MEDIAN"
 #define QC_GEO_EXPk_STDEV   QC_GEO_PREFIX"EXP%d FWHM STDEV"
+#define QC_GEO_FWHM_MEAN    QC_GEO_PREFIX"FWHM MEAN"
+#define QC_GEO_FWHM_STDEV   QC_GEO_PREFIX"FWHM STDEV"
 #define QC_GEO_IFUi_ANGLE   QC_GEO_PREFIX"IFU%hhu ANGLE"
 #define QC_GEO_IFUi_WLENj   QC_GEO_PREFIX"IFU%hhu WLEN%d"
 #define QC_GEO_IFUi_MEANj   QC_GEO_PREFIX"IFU%hhu WLEN%d FLUX MEAN"
 #define QC_GEO_IFUi_MEDIANj QC_GEO_PREFIX"IFU%hhu WLEN%d FLUX MEDIAN"
 #define QC_GEO_IFUi_STDEVj  QC_GEO_PREFIX"IFU%hhu WLEN%d FLUX STDEV"
+#define QC_GEO_IFUi_GAP     QC_GEO_PREFIX"IFU%hhu GAPPOS MEAN"
+#define QC_GEO_GAPS_MEAN    QC_GEO_PREFIX"GAPPOS MEAN"
+#define QC_GEO_GAPS_STDEV   QC_GEO_PREFIX"GAPPOS STDEV"
 #define QC_GEO_MASK_ANGLE   QC_GEO_PREFIX"MASK ANGLE"
 #define QC_GEO_SMOOTH_NX    QC_GEO_PREFIX"SMOOTH NX"
 #define QC_GEO_SMOOTH_NY    QC_GEO_PREFIX"SMOOTH NY"
@@ -293,6 +312,14 @@
 #define QC_ALIGN_NMATCHi          "ESO QC EXPALIGN NMATCH%d"
 #define QC_ALIGN_NMATCH_MIN       "ESO QC EXPALIGN NMATCH MIN"
 #define QC_ALIGN_NOMATCH          "ESO QC EXPALIGN NOMATCH"
+#define QC_ALIGN_DRA_MIN           "ESO QC EXPALIGN OFFSET RA MIN"
+#define QC_ALIGN_DRA_MAX           "ESO QC EXPALIGN OFFSET RA MAX"
+#define QC_ALIGN_DRA_MEAN          "ESO QC EXPALIGN OFFSET RA MEAN"
+#define QC_ALIGN_DRA_STDEV         "ESO QC EXPALIGN OFFSET RA STDEV"
+#define QC_ALIGN_DDEC_MIN          "ESO QC EXPALIGN OFFSET DEC MIN"
+#define QC_ALIGN_DDEC_MAX          "ESO QC EXPALIGN OFFSET DEC MAX"
+#define QC_ALIGN_DDEC_MEAN         "ESO QC EXPALIGN OFFSET DEC MEAN"
+#define QC_ALIGN_DDEC_STDEV        "ESO QC EXPALIGN OFFSET DEC STDEV"
 
 /* Astrometric solution QC headers */
 #define QC_ASTROMETRY_NSTARS "ESO QC ASTRO NSTARS"
@@ -303,4 +330,9 @@
 #define QC_ASTROMETRY_RESX   "ESO QC ASTRO MEDRES X"
 #define QC_ASTROMETRY_RESY   "ESO QC ASTRO MEDRES Y"
 
+/* Non-linearity gain QC headers */
+#define QC_LINGAIN_PREFIX     "ESO QC LINGAIN "
+#define QC_LINGAIN_GFITi_RMS  QC_LINGAIN_PREFIX "GFIT%u RMS"
+#define QC_LINGAIN_NLFITi_RMS QC_LINGAIN_PREFIX "NLFIT%u RMS"
+
 #endif /* MUSE_DFS_H */
