@@ -31,6 +31,7 @@
 #include <math.h>
 
 #include "muse_cplwrappers.h"
+#include "muse_utils.h"
 #include "muse_findstars.h"
 
 /*----------------------------------------------------------------------------*
@@ -360,126 +361,6 @@ _muse_centroid_offset(double *offset, unsigned short axis,
 }
 
 
-/*----------------------------------------------------------------------------*/
-/**
-  @private
-  @brief  Compute the convolution of an image with a kernel.
-  @param  aImage  The image to convolve.
-  @param  aKernel The convolution kernel.
-  @return On success the convoluted image is returned, and @c NULL if an
-          error occurred.
-
-  The function convolves the input image @em aImage with the convolution
-  kernel @em aKernel using an FFT. If @em aImage has an odd number of pixels
-  along the y-axis, the last image row is discarded to make it a size even,
-  however, the size of @em aImage along the x-axis must be even and an
-  error is returned if it is not.
-
-  @error{set CPL_ERROR_NULL_INPUT\, return NULL, a parameter is NULL}
-  @error{set CPL_ERROR_IVALID_TYPE\, return NULL, aImage is not if type double}
-  @error{set CPL_ERROR_INCOMPATIBLE_INPUT\, return NULL, invalid image size}
-
- */
-/*----------------------------------------------------------------------------*/
-static cpl_image *
-_muse_convolve(const cpl_image *aImage, const cpl_matrix *aKernel)
-{
-  cpl_ensure(aImage && aKernel, CPL_ERROR_NULL_INPUT, NULL);
-
-  cpl_size nx = cpl_image_get_size_x(aImage);
-  cpl_size ny = cpl_image_get_size_y(aImage);
-  cpl_size nc = cpl_matrix_get_ncol(aKernel);
-  cpl_size nr = cpl_matrix_get_nrow(aKernel);
-
-  cpl_ensure(cpl_image_get_type(aImage) == CPL_TYPE_DOUBLE,
-             CPL_ERROR_INVALID_TYPE, NULL);
-  cpl_ensure(nx % 2 == 0, CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
-
-  cpl_size kstart[2] = {(nx - nc) / 2, (ny - nr) / 2};
-  cpl_size kend[2]   = {kstart[0] + nc, kstart[1] + nr};
-
-  cpl_image *kernel  = cpl_image_new(nx, ny, CPL_TYPE_DOUBLE);
-  double *_kernel  = cpl_image_get_data_double(kernel);
-
-  const double *_aKernel = cpl_matrix_get_data_const(aKernel);
-  cpl_size iy;
-  for (iy = 0; iy < ny; ++iy) {
-    cpl_size ix;
-    for (ix = 0; ix < nx; ++ix) {
-      cpl_size idx = nx * iy + ix;
-      cpl_boolean inside = ((ix >= kstart[0]) && (ix < kend[0])) &&
-                           ((iy >= kstart[1]) && (iy < kend[1]));
-      if (inside) {
-        _kernel[idx] = _aKernel[nc * (iy - kstart[1]) + (ix - kstart[0])];
-      }
-    }
-  }
-
-  cpl_size nxhalf = nx / 2 + 1;
-  cpl_image *fft_image  = cpl_image_new(nxhalf, ny, CPL_TYPE_DOUBLE_COMPLEX);
-  cpl_image *fft_kernel = cpl_image_new(nxhalf, ny, CPL_TYPE_DOUBLE_COMPLEX);
-
-  cpl_error_code status;
-  status = cpl_fft_image(fft_image, aImage, CPL_FFT_FORWARD);
-  if (status != CPL_ERROR_NONE) {
-    cpl_image_delete(fft_kernel);
-    cpl_image_delete(fft_image);
-    cpl_image_delete(kernel);
-    cpl_error_set_message(__func__, CPL_ERROR_INCOMPATIBLE_INPUT,
-                          "FFT of input image failed!");
-    return NULL;
-  }
-  status = cpl_fft_image(fft_kernel, kernel, CPL_FFT_FORWARD);
-  if (status != CPL_ERROR_NONE) {
-    cpl_image_delete(fft_kernel);
-    cpl_image_delete(fft_image);
-    cpl_image_delete(kernel);
-    cpl_error_set_message(__func__, CPL_ERROR_INCOMPATIBLE_INPUT,
-                          "FFT of convolution kernel failed!");
-    return NULL;
-  }
-  cpl_image_delete(kernel);
-
-  double complex *_fft_image  = cpl_image_get_data_double_complex(fft_image);
-  double complex *_fft_kernel = cpl_image_get_data_double_complex(fft_kernel);
-
-  /* Convolve the input image with the kernel. Compute the two FFTs, for      *
-   * the image and the kernel and multiply the results.                       *
-   *                                                                          *
-   * After the forward transform the zero frequency is stored in the 4        *
-   * corners of the result image, and not in the center as one may            *
-   * expect. In order to get a correct convolution of the image the input     *
-   * buffer of the inverse transformation must be rearranged such that        *
-   * the zero frequency appears in the center. This is done by multiplying    *
-   * all results at odd index positions in the buffer by -1, which            *
-   * effectively swaps the quadrants of the frequency plane.                  *
-   * see: www.mvkonnik.info/2014/06/fft-ifft-and-why-do-we-need-fftshift.html */
-
-  for (iy = 0; iy < ny; ++iy) {
-    cpl_size ix;
-    for (ix = 0; ix < nxhalf; ++ix) {
-      cpl_size idx = nxhalf * iy + ix;
-      int sign = ((ix + iy) % 2) ? -1 : 1;
-      _fft_image[idx] *= sign * _fft_kernel[idx] / (nx * ny);
-    }
-  }
-  cpl_image_delete(fft_kernel);
-
-  cpl_image *result = cpl_image_new(nx, ny, CPL_TYPE_DOUBLE);
-  status = cpl_fft_image(result, fft_image, CPL_FFT_BACKWARD | CPL_FFT_NOSCALE);
-  if (status != CPL_ERROR_NONE) {
-    cpl_image_delete(result);
-    cpl_image_delete(fft_image);
-    cpl_error_set_message(__func__, CPL_ERROR_INCOMPATIBLE_INPUT,
-                          "Backward FFT of convolution result failed!");
-    return NULL;
-  }
-  cpl_image_delete(fft_image);
-
-  return result;
-}
-
-
 /* Type independent shortcut for numerous computations of the square of *
  * a value in the following function.                                   */
 #define MUSE_SQR(x)  ((x) * (x))
@@ -785,7 +666,7 @@ muse_find_stars(const cpl_image *aImage, double aHmin, double aFwhm,
 
   /* Convolve the image with the kernel*/
   cpl_msg_debug(__func__, "Beginning convolution of image.");
-  cpl_image *himage = _muse_convolve(aImage, ckernel);
+  cpl_image *himage = muse_convolve_image(aImage, ckernel);
 
   cpl_matrix_delete(ckernel);
   ckernel = NULL;
