@@ -41,9 +41,6 @@
  *                              Defines                                       *
  *----------------------------------------------------------------------------*/
 
-#define KEY_ASSOC                    "ASSOC"
-#define KEY_ASSOC_COMMENT            "Associated file category"
-#define KEY_ASSOC_VALUE_IMAGE        "ANCILLARY.IMAGE"
 #define KEY_ASSON                    "ASSON"
 #define KEY_ASSON_COMMENT            "Associated file name"
 #define KEY_DEC                      "DEC"
@@ -67,6 +64,7 @@
 #define KEY_PRODCATG                 "PRODCATG"
 #define KEY_PRODCATG_COMMENT         "Data product category"
 #define KEY_PRODCATG_VALUE_IFS_CUBE  "SCIENCE.CUBE.IFS"
+#define KEY_PRODCATG_VALUE_FOV_IMAGE "ANCILLARY.IMAGE"
 #define KEY_PROG_ID                  "PROG_ID"
 #define KEY_PROG_ID_COMMENT          "ESO programme identification"
 #define KEY_PROG_ID_VALUE_MULTIPLE   "MULTI"
@@ -120,8 +118,7 @@
   KEY_REFERENC "|" \
   KEY_NCOMBINE "|" \
   KEY_PROV "[0-9]+|" \
-  KEY_ASSON "[0-9]+|" \
-  KEY_ASSOC "[0-9]+" ")$"
+  KEY_ASSON "[0-9]+" ")$"
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -475,8 +472,15 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
   cpl_ensure(aWlenMax > aWlenMin, CPL_ERROR_ILLEGAL_INPUT, 0.);
   cpl_ensure(aFwhm > 0., CPL_ERROR_ILLEGAL_INPUT, 0.);
 
-  /* Create white light image */
+  /* Minimum number of valid data pixel needed to perform the computation  *
+   * of the magnitude limit. This is given by using the standard deviation *
+   * in the computation of the limiting magnitude                          */
+  const cpl_size min_valid = 2;
+
+  /* Create white light image and encode all invalid pixels as NaN for *
+   * the following analysis.                                           */
   muse_image *fov = muse_datacube_collapse((muse_datacube *)aCube, NULL);
+  muse_image_dq_to_nan(fov);
 
   cpl_size nx = cpl_image_get_size_x(fov->data);
   cpl_size ny = cpl_image_get_size_y(fov->data);
@@ -566,16 +570,42 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
   cpl_mask_filter(fov_mask, fov_invalid, mkernel,
                   CPL_FILTER_DILATION, CPL_BORDER_ZERO);
   cpl_mask_delete(mkernel);
-  cpl_mask_delete(fov_invalid);
+
+  /* The filtering of the mask leaves an nhalf pixel wide border on each   *
+   * side of the mask image which are not flagged. These are set as masked *
+   * here.                                                                 *
+   */
+  cpl_binary *_fov_mask = cpl_mask_get_data(fov_mask);
+
+  cpl_size ipixel;
+  for (ipixel = 0; ipixel < npixel; ++ipixel) {
+    cpl_size _x = ipixel % _nx;
+    cpl_size _y = ipixel / _nx;
+    if (((_x < nhalf) ||(_x > (_nx - nhalf - 1))) ||
+        ((_y < nhalf) ||(_y > (_ny - nhalf - 1)))) {
+      _fov_mask[_y * _nx + _x] = CPL_BINARY_1;
+    }
+  }
+
+  /* Check whether enough valid pixels are left for the following analysis. *
+   * If not enough valid pixels are found revert the dilated mask to the    *
+   * original and use this instead.                                         */
+  if (npixel - cpl_mask_count(fov_mask) < min_valid) {
+    cpl_msg_debug(__func__, "Number of valid pixels in the dilated mask is"
+                  "less than 2! Falling back to the original mask!");
+    cpl_mask_delete(fov_mask);
+    fov_mask = fov_invalid;
+    fov_invalid = NULL;
+  } else {
+    cpl_mask_delete(fov_invalid);
+  }
 
 #ifndef USE_HISTOGRAM
   const double *_fov_smooth = cpl_image_get_data_double_const(fov_smooth);
-  cpl_binary *_fov_mask = cpl_mask_get_data(fov_mask);
 
   double *_fov_valid = cpl_calloc(npixel, sizeof *_fov_valid);
 
   cpl_size nvalid = 0;
-  cpl_size ipixel;
   for (ipixel = 0; ipixel < npixel; ++ipixel) {
     if (_fov_mask[ipixel] == CPL_BINARY_0) {
       _fov_valid[nvalid] = _fov_smooth[ipixel];
@@ -625,9 +655,7 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
   double *hdata = cpl_vector_get_data(histogram);
 
   const double *_fov_smooth = cpl_image_get_data_double_const(fov_smooth);
-  cpl_binary *_fov_mask = cpl_mask_get_data(fov_mask);
 
-  cpl_size ipixel;
   for (ipixel = 0; ipixel < npixel; ++ipixel) {
     if ((_fov_mask[ipixel] == CPL_BINARY_0) &&
         (_fov_smooth[ipixel] >= hmin) && (_fov_smooth[ipixel] <= hmax)) {
@@ -655,7 +683,7 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
   cpl_vector_delete(bins);
 
   double abmaglimit = 0.;
-  if ((cpl_errorstate_get() != status) && (ecode != CPL_ERROR_CONTINUE)) {
+  if (!cpl_errorstate_is_equal(status) && (ecode != CPL_ERROR_CONTINUE)) {
     cpl_msg_debug(__func__, "Fit of a Gaussian to the histogram peak failed!");
     cpl_errorstate_set(status);
   } else {
@@ -699,6 +727,9 @@ muse_idp_properties_delete(muse_idp_properties *aProperties)
     cpl_array_delete(aProperties->progid);
     cpl_propertylist_delete(aProperties->prov);
     cpl_array_delete(aProperties->asson);
+
+    /* TODO: Remove deallocator call for assoc once it has been *
+     * removed from the interface.                              */
     cpl_array_delete(aProperties->assoc);
     cpl_free((char *)aProperties->prodcatg);
     cpl_free((char *)aProperties->procsoft);
@@ -785,7 +816,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
         }
       }
 
-      if (cpl_errorstate_get() != _status) {
+      if (!cpl_errorstate_is_equal(status)) {
         if (cpl_error_get_code() == CPL_ERROR_DATA_NOT_FOUND) {
           cpl_msg_debug(__func__, "Keyword \"INS.MODE\" is missing in '%s'!",
                         filename);
@@ -814,7 +845,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
       double fwhmstart = muse_pfits_get_fwhm_start(_header);
       double fwhmend   = muse_pfits_get_fwhm_end(_header);
 
-      if (cpl_errorstate_get() != _status) {
+      if (!cpl_errorstate_is_equal(status)) {
           cpl_msg_debug(__func__, "Missing or invalid seeing information "
                   "(\"TEL.AMBI.FWHM.START\", \"TEL.AMBI.FWHM.END\") in "
                   "exposure '%s'", filename);
@@ -847,6 +878,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
       if (prov) {
         char *name = cpl_sprintf("PROV%-u", ++nraw);
         cpl_propertylist_append_string(properties->prov, name, prov);
+        cpl_free(name);
       } else {
         unsigned int iraw = 1;
         prov = muse_pfits_get_raw_filename(_header, iraw);
@@ -864,7 +896,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
   }
   cpl_table_delete(exposures);
 
-  if (cpl_errorstate_get() != status) {
+  if (!cpl_errorstate_is_equal(status)) {
     muse_idp_properties_delete(properties);
     return NULL;
   }
@@ -885,7 +917,6 @@ muse_idp_properties_collect(muse_processing *aProcessing,
 
   cpl_size nframes = cpl_frameset_get_size(aProcessing->outframes);
   properties->asson = cpl_array_new(nframes, CPL_TYPE_STRING);
-  properties->assoc = cpl_array_new(nframes, CPL_TYPE_STRING);
 
   cpl_size iancillary = 0;
   cpl_size nptotal = 0;
@@ -898,8 +929,6 @@ muse_idp_properties_collect(muse_processing *aProcessing,
     if (strcmp(tag, MUSE_TAG_IMAGE_FOV) == 0) {
       cpl_array_set_string(properties->asson, iancillary,
                            cpl_frame_get_filename(frame));
-      cpl_array_set_string(properties->assoc, iancillary,
-                           KEY_ASSOC_VALUE_IMAGE);
 
       /* Estimate the number of illuminated pixels of the combined    *
        * field-of-view. The maximum number of valid pixels across all *
@@ -926,7 +955,6 @@ muse_idp_properties_collect(muse_processing *aProcessing,
     }
   }
   cpl_array_set_size(properties->asson, iancillary);
-  cpl_array_set_size(properties->assoc, iancillary);
 
   /* Estimate exposure time per pixel. If the number of illuminated pixels *
    * cannot be computed, or if there are no "valid" pixels the exposure    *
@@ -1015,7 +1043,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
    * histogram bin size of 0.2 sigma.                                       */
 
   double pixnoise = muse_idp_compute_pixnoise(aCube, 0, 25., 0.04);
-  if (cpl_errorstate_get() != status) {
+  if (!cpl_errorstate_is_equal(status)) {
     double ron  = 0.;
     double gain = 0.;
 
@@ -1065,7 +1093,7 @@ muse_idp_properties_collect(muse_processing *aProcessing,
                                   properties->wlenrange[0] * nm2Angstrom,
                                   properties->wlenrange[1] * nm2Angstrom,
                                   properties->skyres / CPL_MAX(xscale, yscale));
-  if (cpl_errorstate_get() != status) {
+  if (!cpl_errorstate_is_equal(status)) {
     properties->abmaglimit = -99.;
     cpl_errorstate_set(status);
   } else {
@@ -1118,8 +1146,6 @@ muse_idp_properties_update(cpl_propertylist *aHeader,
              CPL_ERROR_ILLEGAL_INPUT, CPL_ERROR_ILLEGAL_INPUT);
   cpl_ensure(cpl_propertylist_get_size(aProperties->prov) >= aProperties->ncombine,
              CPL_ERROR_ILLEGAL_INPUT, CPL_ERROR_ILLEGAL_INPUT);
-  cpl_ensure(cpl_array_get_size(aProperties->asson) == cpl_array_get_size(aProperties->assoc),
-             CPL_ERROR_ILLEGAL_INPUT, CPL_ERROR_ILLEGAL_INPUT);
 
   cpl_propertylist_erase_regexp(aHeader, CLEAN_KEYS_REGEXP, 0);
 
@@ -1220,13 +1246,9 @@ muse_idp_properties_update(cpl_propertylist *aHeader,
   cpl_size idx;
   for (idx = 0; idx < cpl_array_get_size(aProperties->asson); ++idx) {
     char *name = cpl_sprintf(KEY_ASSON "%-" CPL_SIZE_FORMAT, idx + 1);
-    char *type = cpl_sprintf(KEY_ASSOC "%-" CPL_SIZE_FORMAT, idx + 1);
     cpl_propertylist_update_string(aHeader, name,
                                    cpl_array_get_string(aProperties->asson, idx));
-    cpl_propertylist_update_string(aHeader, type,
-                                   cpl_array_get_string(aProperties->assoc, idx));
     cpl_free(name);
-    cpl_free(type);
   }
 
   cpl_propertylist_update_string(aHeader, KEY_PRODCATG, aProperties->prodcatg);
@@ -1278,6 +1300,35 @@ muse_idp_properties_update(cpl_propertylist *aHeader,
                                        aProperties->wlerror);
   cpl_propertylist_set_comment(aHeader, KEY_SPEC_ERR, KEY_SPEC_ERR_COMMENT);
 
+  /* Fallback required for IDPs */
+
+  if (!cpl_propertylist_has(aHeader, "CSYER1")) {
+    cpl_propertylist_update_double(aHeader, "CSYER1", -1.);
+    cpl_propertylist_set_comment(aHeader, "CSYER1",
+                                 "[deg] Systematic error in coordinate");
+  }
+  if (!cpl_propertylist_has(aHeader, "CSYER2")) {
+    cpl_propertylist_update_double(aHeader, "CSYER2", -1.);
+    cpl_propertylist_set_comment(aHeader, "CSYER2",
+                                 "[deg] Systematic error in coordinate");
+  }
+
   return CPL_ERROR_NONE;
 }
+
+cpl_error_code
+muse_idp_properties_update_fov(muse_image *aFov)
+{
+  cpl_error_code status = CPL_ERROR_NONE;
+
+  cpl_ensure(aFov, CPL_ERROR_NULL_INPUT, CPL_ERROR_NULL_INPUT);
+  cpl_ensure(aFov->header, CPL_ERROR_ILLEGAL_INPUT, CPL_ERROR_ILLEGAL_INPUT);
+
+  status = cpl_propertylist_update_string(aFov->header, KEY_PRODCATG,
+                                           KEY_PRODCATG_VALUE_FOV_IMAGE);
+  cpl_propertylist_set_comment(aFov->header, KEY_PRODCATG, KEY_PRODCATG_COMMENT);
+
+  return status;
+}
+
 /**@}*/
