@@ -605,7 +605,12 @@ muse_lsf_cube_save(muse_lsf_cube *aLsfCube, const char *aFileName)
 /**
    @brief Load all LSF cubes for all IFUs into an array.
    @param aProcessing   the processing structure
-   @return array of 48 LSF cubes or NULL on error
+   @return array of up to kMuseNumIFUs LSF cubes or NULL on error
+
+   This function output a warning message, if one of the files from the input
+   frameset cannot be loaded or if the LSFs for one of the IFUs cannot be
+   found.
+
    @cpl_ensure{aProcessing, CPL_ERROR_NULL_INPUT, NULL}
  */
 /*----------------------------------------------------------------------------*/
@@ -621,7 +626,8 @@ muse_lsf_cube_load_all(muse_processing *aProcessing)
     cpl_errorstate es = cpl_errorstate_get();
     cpl_frame *frame = cpl_frameset_get_position(frames, 0);
     if (frame == NULL) {
-      cpl_msg_warning(__func__, "No LSF cube specified for IFU %hhu", ifu);
+      cpl_msg_warning(__func__, "No %s (cube format) specified for IFU %2hhu!",
+                      MUSE_TAG_LSF_PROFILE, ifu);
       cpl_errorstate_set(es); /* swallow the illegal input state */
       cpl_frameset_delete(frames);
       continue;
@@ -629,19 +635,24 @@ muse_lsf_cube_load_all(muse_processing *aProcessing)
     const char *fn = cpl_frame_get_filename(frame);
     lsf[ifu-1] = muse_lsf_cube_load(fn, ifu);
     if (lsf[ifu-1] == NULL) {
-      cpl_msg_info(__func__, "Could not load LSF (CUBE format) from \"%s\"", fn);
+      cpl_msg_warning(__func__, "Could not load LSF (cube format) for IFU %2hhu "
+                      "from \"%s\"!", ifu, fn);
       cpl_frameset_delete(frames);
       muse_lsf_cube_delete_all(lsf);
       return NULL;
     }
+    muse_processing_append_used(aProcessing, frame, CPL_FRAME_GROUP_CALIB, 1);
     cpl_frameset_delete(frames);
     nlsfs++;
   } /* for ifu */
   if (!nlsfs) {
-    cpl_msg_error(__func__, "Did not load any LSF cubes!");
+    cpl_msg_error(__func__, "Did not load any %ss (cube format)!",
+                  MUSE_TAG_LSF_PROFILE);
     muse_lsf_cube_delete_all(lsf);
     return NULL;
   } /* if none loaded */
+  cpl_msg_info(__func__, "Successfully loaded %s%hhu %ss (cube format).",
+               nlsfs == kMuseNumIFUs ? "all ": "", nlsfs, MUSE_TAG_LSF_PROFILE);
   return lsf;
 } /* muse_lsf_cube_load_all() */
 
@@ -683,20 +694,19 @@ muse_lsf_cube_load(const char *aFileName, unsigned char aIFU)
       return NULL;
     }
   } /* if no LSF_PROFILE extension */
+  cpl_free(extname);
 
   muse_lsf_cube *lsf = cpl_calloc(1, sizeof(muse_lsf_cube));
   lsf->header = cpl_propertylist_load(aFileName, 0); /* primary header */
   lsf->img = cpl_imagelist_load(aFileName, CPL_TYPE_DOUBLE, ext);
   lsf->wcs = cpl_calloc(1, sizeof(muse_wcs));
   if (lsf->img == NULL) {
-    cpl_free(extname);
     muse_lsf_cube_delete(lsf);
     return NULL;
   }
   /* now load the WCS from the extension header */
   cpl_propertylist *header = cpl_propertylist_load(aFileName, ext);
   if (header == NULL) {
-    cpl_free(extname);
     muse_lsf_cube_delete(lsf);
     return NULL;
   }
@@ -714,9 +724,6 @@ muse_lsf_cube_load(const char *aFileName, unsigned char aIFU)
   // muse_pfits_get_cunit(header, 1) "Angstrom"
   // muse_pfits_get_cunit(header, 2) "Angstrom"
   cpl_propertylist_delete(header);
-  cpl_msg_info(__func__, "Loaded LSF cube \"%s[%s]\" (ext %d)", aFileName,
-               extname ? extname : "LSF_PROFILE", ext);
-  cpl_free(extname);
 
   return lsf;
 } /* muse_lsf_cube_load() */
