@@ -300,7 +300,7 @@ muse_cpl_optimize_lvmq(void *aData, cpl_array *aPar, int aSize,
   double cpufini = cpl_test_get_cputime();
   
   cpl_msg_debug(__func__, "Minimizing finished after %i steps: %s", 
-                control.nfev,
+                control.nfev / ((int)cpl_array_get_size(aPar)+1),
                 lm_infmsg[control.info]);
   
   cpl_msg_debug(__func__, "processing time %.3fs (%.3fs CPU, %d CPUs)", 
@@ -751,9 +751,9 @@ static void lm_lmdif(int m, int n, double *x, double *fvec, double ftol,
         step = eps;
 	    xd[j] += step;
 	    int infod = 0;
-	    (*evaluate) (xd, m, wa5, data, &infod);
+	    (*evaluate) (xd, m, wa5, data, &infod); ++(*nfev);
       if( printout )
-        (*printout) (__func__, n, xd, m, wa5, data, 1, iter, ++(*nfev));
+        (*printout) (__func__, n, xd, m, wa5, data, 1, iter, *nfev);
 	    if (infod < 0) {/* user requested break */
         *info = infod;
         cpl_free(wa5);
