@@ -58,6 +58,23 @@ muse_pfits_get_arcfile(const cpl_propertylist *aHeaders)
   return value;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the origfile
+  @param    aHeaders       property list/headers to read from
+  @return   pointer to statically allocated string or NULL on error
+
+  Queries FITS header ORIGFILE
+ */
+/*----------------------------------------------------------------------------*/
+const char *
+muse_pfits_get_origfile(const cpl_propertylist *aHeaders)
+{
+  const char *value = cpl_propertylist_get_string(aHeaders, "ORIGFILE");
+  cpl_ensure(value, cpl_error_get_code(), NULL);
+  return value;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    find out the pipefile
@@ -1214,7 +1231,7 @@ muse_pfits_get_agy_rms(const cpl_propertylist *aHeaders)
 
 /*----------------------------------------------------------------------------*/
 /**
-  @brief    find out the image analysis FWHM from a linear fit (in arcsec)
+  @brief    find out the image analysis FWHM corrected by airmass (in arcsec)
   @param    aHeaders       property list/headers to read from
   @return   the requested value or 0.0 on error
 
@@ -1230,6 +1247,24 @@ muse_pfits_get_ia_fwhm(const cpl_propertylist *aHeaders)
   return value;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the image analysis FWHM from a linear fit (in arcsec)
+  @param    aHeaders       property list/headers to read from
+  @return   the requested value or 0.0 on error
+
+  Queries FITS header ESO TEL IA FWHMLIN
+ */
+/*----------------------------------------------------------------------------*/
+double
+muse_pfits_get_ia_fwhmlin(const cpl_propertylist *aHeaders)
+{
+  cpl_errorstate prestate = cpl_errorstate_get();
+  const double value = cpl_propertylist_get_double(aHeaders, "ESO TEL IA FWHMLIN");
+  cpl_ensure(cpl_errorstate_is_equal(prestate), cpl_error_get_code(), 0.0);
+  return value;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    find out the MUSE derotator mode
@@ -1590,4 +1625,103 @@ muse_pfits_get_pospos(const cpl_propertylist *aHeaders, unsigned short aEncoder)
   return value;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the observation block id
+  @param    aHeaders       property list/headers to read from
+  @return   the requested value or -1 on error
+
+  Queries FITS header for ESO.OBS.ID
+ */
+/*----------------------------------------------------------------------------*/
+long
+muse_pfits_get_obsid(const cpl_propertylist *aHeaders)
+{
+  cpl_errorstate prestate = cpl_errorstate_get();
+  const long value = cpl_propertylist_get_long(aHeaders, "ESO OBS ID");
+  cpl_ensure(cpl_errorstate_is_equal(prestate), cpl_error_get_code(), -1);
+  return value;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the ESO program identification
+  @param    aHeaders       property list/headers to read from
+  @return   the requested value or NULL on error
+
+  Queries FITS header for ESO.OBS.PROG.ID
+ */
+/*----------------------------------------------------------------------------*/
+const char *
+muse_pfits_get_progid(const cpl_propertylist *aHeaders)
+{
+  cpl_errorstate prestate = cpl_errorstate_get();
+  const char *value = cpl_propertylist_get_string(aHeaders, "ESO OBS PROG ID");
+  cpl_ensure(cpl_errorstate_is_equal(prestate), cpl_error_get_code(), NULL);
+  return value;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the value of the flux calibration flag
+  @param    aHeaders       property list/headers to read from
+  @param    idx            recipe index
+  @return   the requested value or NULL on error
+
+  Queries FITS header for ESO.PRO.REC<idx>.PIPE.ID
+ */
+/*----------------------------------------------------------------------------*/
+const char *
+muse_pfits_get_pipe_id(const cpl_propertylist *aHeaders, unsigned int idx)
+{
+  cpl_ensure(aHeaders, CPL_ERROR_NULL_INPUT, NULL);
+  char *key = cpl_sprintf("ESO PRO REC%-u PIPE ID", idx);
+  cpl_errorstate prestate = cpl_errorstate_get();
+  const char *value = cpl_propertylist_get_string(aHeaders, key);
+  cpl_errorstate_set(prestate);
+  cpl_free(key);
+  return value;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the i-th raw file name.
+  @param    aHeaders       property list/headers to read from
+  @param    idx            raw file index
+  @return   the requested value or NULL on error
+
+  Queries FITS header for ESO.PRO.REC1.RAW<idx>.NAME
+ */
+/*----------------------------------------------------------------------------*/
+const char *
+muse_pfits_get_raw_filename(const cpl_propertylist *aHeaders, unsigned int idx)
+{
+  cpl_ensure(aHeaders, CPL_ERROR_NULL_INPUT, NULL);
+  char *key = cpl_sprintf("ESO PRO REC1 RAW%-u NAME", idx);
+  cpl_errorstate prestate = cpl_errorstate_get();
+  const char *value = cpl_propertylist_get_string(aHeaders, key);
+  cpl_errorstate_set(prestate);
+  cpl_free(key);
+  return value;
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    find out the ancestor of a file.
+  @param    aHeaders       property list/headers to read from
+  @return   the requested value or NULL on error
+
+  Queries FITS header for ESO.PRO.ANCESTOR
+ */
+/*----------------------------------------------------------------------------*/
+const char *
+muse_pfits_get_ancestor(const cpl_propertylist *aHeaders)
+{
+  cpl_ensure(aHeaders, CPL_ERROR_NULL_INPUT, NULL);
+  cpl_errorstate prestate = cpl_errorstate_get();
+  const char *value = cpl_propertylist_get_string(aHeaders, "ESO PRO ANCESTOR");
+  cpl_errorstate_set(prestate);
+  return value;
+}
+
 /**@}*/
