@@ -40,11 +40,17 @@
  *----------------------------------------------------------------------------*/
 /* DFS stuff */
 const char *muse_pfits_get_arcfile(const cpl_propertylist *);
+const char *muse_pfits_get_origfile(const cpl_propertylist *);
 const char *muse_pfits_get_pipefile(const cpl_propertylist *);
+const char *muse_pfits_get_ancestor(const cpl_propertylist *);
 const char *muse_pfits_get_dpr_type(const cpl_propertylist *);
 const char *muse_pfits_get_dpr_catg(const cpl_propertylist *);
 const char *muse_pfits_get_pro_type(const cpl_propertylist *);
 const char *muse_pfits_get_pro_catg(const cpl_propertylist *);
+const char *muse_pfits_get_raw_filename(const cpl_propertylist *, unsigned int);
+const char *muse_pfits_get_pipe_id(const cpl_propertylist *, unsigned int);
+const char *muse_pfits_get_progid(const cpl_propertylist *);
+long muse_pfits_get_obsid(const cpl_propertylist *);
 
 /* instrument properties */
 muse_ins_mode muse_pfits_get_mode(const cpl_propertylist *);
@@ -112,6 +118,7 @@ double muse_pfits_get_agx_rms(const cpl_propertylist *);
 double muse_pfits_get_agy_avg(const cpl_propertylist *);
 double muse_pfits_get_agy_rms(const cpl_propertylist *);
 double muse_pfits_get_ia_fwhm(const cpl_propertylist *);
+double muse_pfits_get_ia_fwhmlin(const cpl_propertylist *aHeaders);
 
 /* ambient telescope properties */
 double muse_pfits_get_temp(const cpl_propertylist *);
