@@ -186,10 +186,11 @@ muse_pixgrid_create(muse_pixtable *aPixtable, cpl_propertylist *aHeader,
   double crval3 = muse_pfits_get_crval(aHeader, 3),
          crpix3 = muse_pfits_get_crpix(aHeader, 3),
          cd33 = muse_pfits_get_cd(aHeader, 3, 3);
+  const char *ctype3 = muse_pfits_get_ctype(aHeader, 3);
   muse_wcs *wcs = muse_wcs_new(aHeader);
   wcs->iscelsph = wcstype == MUSE_PIXTABLE_WCS_CELSPH;
-  cpl_boolean loglambda = !strncmp(muse_pfits_get_ctype(aHeader, 3),
-                                   "AWAV-LOG", 9);
+  cpl_boolean loglambda = ctype3 && (!strncmp(ctype3, "AWAV-LOG", 9) ||
+                                     !strncmp(ctype3, "WAVE-LOG", 9));
   /* get all (relevant) table columns for easy pointer access */
   double ptxoff = 0., ptyoff = 0.;
   if (wcs->iscelsph) {
@@ -263,7 +264,7 @@ muse_pixgrid_create(muse_pixtable *aPixtable, cpl_propertylist *aHeader,
         y = lround(ypx) - 1,
         z = lround((lbda[n] - crval3) / cd33 + crpix3) - 1;
     if (loglambda) {
-      z = lround(crval3 / cd33 * log(lbda[n] / crval3));
+      z = lround(crval3 / cd33 * log(lbda[n] / crval3)) + crpix3 - 1;
     }
     cpl_size idx = muse_pixgrid_get_index(pixgrid, x, y, z, CPL_TRUE);
 #ifdef ESO_ENABLE_DEBUG
