@@ -205,6 +205,9 @@ extern const muse_cpltable_def muse_pixtable_def[];
 /** Combined exposures that went into this pixel table */
 #define MUSE_HDR_PT_COMBINED           "ESO DRS MUSE PIXTABLE COMBINED" /* int */
 #define MUSE_HDR_PT_COMBINED_COMMENT   "Combined exposures that went into this pixel table"
+/** Spectral type code, set after converting from air to vacuum */
+#define MUSE_HDR_PT_SPEC_TYPE          "ESO DRS MUSE PIXTABLE SPECTYPE" /* string */
+#define MUSE_HDR_PT_SPEC_TYPE_COMMENT  "FITS spectral type code of wavelength"
 
 /* regular expression to remove all pixtable-related keyword, *
  * e.g. when transforming to 2D image or 3D cube              */
