@@ -40,6 +40,7 @@
 #include "muse_rvcorrect.h"
 #include "muse_utils.h"
 #include "muse_wcs.h"
+#include "muse_idp.h"
 
 #include "muse_lsf_params.h"
 #ifdef USE_LSF_PARAMS
@@ -47,9 +48,6 @@
 #endif
 
 #undef CREATE_IDP
-#ifdef CREATE_IDP
-#include "muse_idp.h"
-#endif
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -982,6 +980,12 @@ muse_postproc_cube_resample_and_collapse(muse_processing *aProcessing,
                                       cpl_array_get_string(filters, i));
       cpl_propertylist_update_string(fov->header, MUSE_HDR_FILTER,
                                       cpl_array_get_string(filters, i));
+      if (aFormat == MUSE_CUBE_TYPE_SDP) {
+        if (muse_idp_properties_update_fov(fov) != CPL_ERROR_NONE) {
+            cpl_msg_warning(__func__, "Writing IDP keywords to field-of-view "
+                            "image failed!");
+        }
+      }
       muse_processing_save_image(aProcessing, -1, fov, MUSE_TAG_IMAGE_FOV);
       muse_image_delete(fov);
     }
