@@ -69,8 +69,7 @@ typedef enum {
 typedef enum {
   MUSE_POSTPROC_SKYMETHOD_NONE = 0,
   MUSE_POSTPROC_SKYMETHOD_MODEL,
-  MUSE_POSTPROC_SKYMETHOD_SIMPLE,
-  MUSE_POSTPROC_SKYMETHOD_ROWBYROW
+  MUSE_POSTPROC_SKYMETHOD_SIMPLE
 } muse_postproc_skymethod;
 
 /*----------------------------------------------------------------------------*/
