@@ -435,7 +435,7 @@ muse_processing_new_frame(muse_processing *aProcessing, int aIFU,
   cpl_frame_set_level(frame,
                       muse_processing_get_frame_level(aProcessing->recipe,
                                                       aTag));
-  if (cpl_errorstate_get() != prestate) {
+  if (!cpl_errorstate_is_equal(prestate)) {
     cpl_msg_error(__func__, "Error while initialising the product frame: %s",
                   cpl_error_get_message());
     cpl_frame_delete(frame);
@@ -533,7 +533,7 @@ muse_processing_save_cube(muse_processing *aProcessing, int aIFU,
       muse_idp_properties_update(((muse_datacube *)aCube)->header, properties);
     }
     muse_idp_properties_delete(properties);
-    if (cpl_errorstate_get() != status) {
+    if (!cpl_errorstate_is_equal(status)) {
       cpl_frame_delete(frame);
       return cpl_error_get_code();
     }
