@@ -77,7 +77,8 @@ typedef enum {
                               *   in extra FITS extensions                  */
   MUSE_CUBE_TYPE_FITS_X,     /**< FITS NAXIS=3 format with 2 extensions plus *
                               *   reconstructed image(s) in extra extensions */
-  MUSE_CUBE_TYPE_LSF         /**< MUSE LSF cube */
+  MUSE_CUBE_TYPE_LSF,        /**< MUSE LSF cube */
+  MUSE_CUBE_TYPE_SDP         /**< MUSE FITS cube with ESO SDP headers */
 } muse_cube_type;
 
 /**@}*/
