@@ -375,7 +375,7 @@ muse_processing_recipeinfo(cpl_plugin *aPlugin)
        cpl_boolean value = cpl_parameter_get_bool(p),
                    dval = cpl_parameter_get_default_bool(p);
        if (value != dval) {
-         cpl_msg_debug(__func__, "--%s = %s [%s]", name,
+         cpl_msg_debug(__func__, "--%s=%s [%s]", name,
                        value ? "true" : "false", dval ? "true" : "false");
          n++;
        }
@@ -385,7 +385,7 @@ muse_processing_recipeinfo(cpl_plugin *aPlugin)
        int value = cpl_parameter_get_int(p),
            dval = cpl_parameter_get_default_int(p);
        if (value != dval) {
-         cpl_msg_debug(__func__, "--%s = %d [%d]", name, value, dval);
+         cpl_msg_debug(__func__, "--%s=%d [%d]", name, value, dval);
          n++;
        }
        break;
@@ -394,7 +394,7 @@ muse_processing_recipeinfo(cpl_plugin *aPlugin)
        double value = cpl_parameter_get_double(p),
               dval = cpl_parameter_get_default_double(p);
        if (value != dval) {
-         cpl_msg_debug(__func__, "--%s = %g [%g]", name, value, dval);
+         cpl_msg_debug(__func__, "--%s=%g [%g]", name, value, dval);
          n++;
        }
        break;
@@ -403,7 +403,7 @@ muse_processing_recipeinfo(cpl_plugin *aPlugin)
        const char *value = cpl_parameter_get_string(p),
                   *dval = cpl_parameter_get_default_string(p);
        if (value && dval && strncmp(value, dval, strlen(dval) + 1)) {
-         cpl_msg_debug(__func__, "--%s = %s [%s]", name, value, dval);
+         cpl_msg_debug(__func__, "--%s=\"%s\" [\"%s\"]", name, value, dval);
          n++;
        }
        break;
@@ -421,7 +421,11 @@ muse_processing_recipeinfo(cpl_plugin *aPlugin)
   cpl_msg_debug(__func__, "relevant environment variables:");
   cpl_msg_indent_more();
   /* print all MUSE* environment variables */
-  /* XXX not sure how to do that */
+  /* XXX not sure how to do that in a portable way, so take a few important ones */
+  char *expuser = getenv("MUSE_EXPERT_USER");
+  if (expuser) {
+    cpl_msg_debug(__func__, "MUSE_EXPERT_USER=%s", expuser);
+  }
   /* print OMP_NUM_THREADS variable */
   char *omp_num_threads = getenv("OMP_NUM_THREADS");
   if (omp_num_threads) {
