@@ -151,73 +151,6 @@ muse_sky_create_skymask(muse_image *aImage, double aMinFraction, double aFractio
   return selectedRegions;
 }
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Mark all pixel above a certain limit as COSMIC
-  @param    aSpectrum   Reference spectrum
-  @param    aPixtable   Pixel table
-  @param    aSigma      sigma rejection level
-  @return   CPL_ERROR_NONE on success, another CPL error code on failure
-
-  Check each selected pixel of the pixel table against the
-  reference spectrum. If the data value of the pixel is higher than the
-  according value of the spectrum + aSigma * variance, it is considered as
-  cosmic. This works well for sky since we assume a homogenious illumination,
-  strong variations are not expected here.
-
-  @error{set and return CPL_ERROR_NULL_INPUT,
-         aSpectrum and/or aPixtable are NULL}
-  @error{set and return CPL_ERROR_ILLEGAL_INPUT, aSigma is not positive}
- */
-/*----------------------------------------------------------------------------*/
-cpl_error_code
-muse_sky_mark_cosmic(cpl_table *aSpectrum, muse_pixtable *aPixtable,
-                     double aSigma)
-{
-  cpl_ensure_code(aSpectrum && aPixtable, CPL_ERROR_NULL_INPUT);
-  cpl_ensure_code(aSigma > 0., CPL_ERROR_ILLEGAL_INPUT);
-
-  float *lbda = cpl_table_get_data_float(aPixtable->table, MUSE_PIXTABLE_LAMBDA);
-  float *data = cpl_table_get_data_float(aPixtable->table, MUSE_PIXTABLE_DATA);
-  int *dq = cpl_table_get_data_int(aPixtable->table, MUSE_PIXTABLE_DQ);
-
-  cpl_size spec_nrows = cpl_table_get_nrow(aSpectrum);
-  double *spec_data = cpl_table_get_data_double(aSpectrum, "data");
-  double *spec_stat = cpl_table_get_data_double(aSpectrum, "stat");
-  double *spec_std = cpl_malloc(spec_nrows * sizeof(double));
-  cpl_size i_spec;
-  for (i_spec = 0; i_spec < spec_nrows; i_spec++) {
-    spec_std[i_spec] = sqrt(spec_stat[i_spec]);
-  }
-
-  /* loop through all selected pixel table rows  */
-  cpl_array *asel = cpl_table_where_selected(aPixtable->table);
-  const cpl_size *sel = cpl_array_get_data_cplsize_const(asel);
-  cpl_size isel, nsel = cpl_array_get_size(asel);
-  cpl_size n_cosmic = 0;
-  for (isel = 0; isel < nsel; isel++) {
-    cpl_size i_row = sel[isel];
-    if ((dq[i_row] != EURO3D_GOODPIXEL)) {
-      continue;
-    }
-    double l = lbda[i_row];
-    i_spec = muse_cpltable_find_sorted(aSpectrum, "lambda", l);
-    if ((i_spec < spec_nrows - 1) && (spec_data[i_spec] < spec_data[i_spec+1])) {
-      i_spec++;
-    }
-    if (spec_data[i_spec] + aSigma * spec_std[i_spec] < data[i_row]) {
-      dq[i_row] = EURO3D_COSMICRAY;
-      n_cosmic++;
-    }
-  }
-  cpl_msg_info(__func__, "Marked %"CPL_SIZE_FORMAT" pixels of %"CPL_SIZE_FORMAT
-               " as cosmic", n_cosmic, nsel);
-
-  cpl_array_delete(asel);
-  cpl_free(spec_std);
-  return CPL_ERROR_NONE;
-} /* muse_sky_mark_cosmic() */
-
 /*----------------------------------------------------------------------------*/
 /**
   @brief  Save sky continuum table to file.
