@@ -134,7 +134,7 @@ cpl_error_code muse_utils_get_centroid(const cpl_matrix *, const cpl_vector *, c
 cpl_error_code muse_utils_fit_multigauss_1d(const cpl_vector *, const cpl_bivector *, cpl_vector *, double *, cpl_vector *, cpl_vector *, double *, double *, cpl_matrix **);
 cpl_error_code muse_utils_fit_moffat_2d(const cpl_matrix *, const cpl_vector *, const cpl_vector *, cpl_array *, cpl_array *, const cpl_array *, double *, double *);
 cpl_polynomial *muse_utils_iterate_fit_polynomial(cpl_matrix *, cpl_vector *, cpl_vector *, cpl_table *, const unsigned int, const double, double *, double *);
-double muse_utils_pixtable_fit_line_gaussian(muse_pixtable *, double, double, double, cpl_array *, cpl_array *);
+double muse_utils_pixtable_fit_line_gaussian(muse_pixtable *, double, double, double, float, float, unsigned char, cpl_array *, cpl_array *);
 cpl_matrix *muse_matrix_new_gaussian_2d(int, int, double);
 
 cpl_error_code muse_utils_copy_modified_header(cpl_propertylist *, cpl_propertylist *, const char *, const char *);
@@ -142,4 +142,8 @@ cpl_error_code muse_utils_set_hduclass(cpl_propertylist *, const char *, const c
 
 void muse_utils_memory_dump(const char *);
 
+muse_image *muse_fov_load(const char *aFilename);
+cpl_image *muse_convolve_image(const cpl_image *aImage, const cpl_matrix *aKernel);
+
+
 #endif /* MUSE_UTILS_H */
