@@ -645,6 +645,10 @@ muse_wcs_locate_sources(muse_pixtable *aPixtable, float aSigma,
   aFAccuracy) until matches are found. Remove the remaining unidentified
   objects.
 
+  The final values used for relative and absolute accuracy and the radius are
+  recorded in the header keywords MUSE_HDR_WCS_RADIUS, MUSE_HDR_WCS_ACCURACY,
+  and MUSE_HDR_WCS_FACCURACY.
+
   Derive the world coordinate plate solution using cpl_wcs_platesol() (taking
   into account shift, 2 scales, and rotation) and add it as cpl_propertylist
   element wcs to aWCSObj.
@@ -808,7 +812,7 @@ muse_wcs_solve(muse_wcs_object *aWCSObj, cpl_table *aReference,
                   dupes ? "(non-unique!) " : "unique ",
                   scale*1800.*(xscale+yscale), angle, radius, aRadius, accuracy,
                   accuracy0);
-    radius /= 1.5; /* next loop with smaller radius, if necessary */
+    radius /= 1.25; /* next loop with smaller radius, if necessary */
   } while (dupes);
   cpl_matrix_delete(data);
   cpl_matrix_delete(patt);
@@ -904,10 +908,254 @@ muse_wcs_solve(muse_wcs_object *aWCSObj, cpl_table *aReference,
   cpl_propertylist_update_float(wcsout, QC_ASTROMETRY_RESX, medresx);
   cpl_propertylist_update_float(wcsout, QC_ASTROMETRY_RESY, medresy);
 
+  /* update header with the final values used, just for information */
+  cpl_propertylist_update_float(wcsout, MUSE_HDR_WCS_RADIUS, radius);
+  cpl_propertylist_set_comment(wcsout, MUSE_HDR_WCS_RADIUS,
+                               MUSE_HDR_WCS_RADIUS_C);
+  cpl_propertylist_update_float(wcsout, MUSE_HDR_WCS_ACCURACY, accuracy);
+  cpl_propertylist_set_comment(wcsout, MUSE_HDR_WCS_ACCURACY,
+                               MUSE_HDR_WCS_ACCURACY_C);
+  cpl_propertylist_update_float(wcsout, MUSE_HDR_WCS_FACCURACY,
+                                accuracy / accuracy0);
+  cpl_propertylist_set_comment(wcsout, MUSE_HDR_WCS_FACCURACY,
+                               MUSE_HDR_WCS_FACCURACY_C);
+
   aWCSObj->wcs = wcsout;
   return rc;
 } /* muse_wcs_solve() */
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief   Find an optimal astrometry solution given a detection image.
+  @param   aWCSObj      the MUSE WCS object
+  @param   aDetSigma    the (negative!) sigma level used for object detection
+  @param   aCentroid    type of centroiding algorithm to use
+  @param   aReference   reference coordinates for the same field
+  @param   aRadius      initial radius for pattern matching in pixels
+  @param   aFAccuracy   factor to set initial accuracy relative to mean position
+                        accuracy in aWCSObj->detected
+  @param   aIter        number of iterations
+  @param   aRejSigma    the rejection threshold
+  @return  CPL_ERROR_NONE on success, another CPL error code on failure
+
+  @note aWCSObj has to contain the cube with the associated detection image, as
+        produced by @ref muse_wcs_locate_sources().
+  @remark  The propertylist returned in aWCSObj->wcs contains the world
+           coordinate solution.
+
+  Repeatedly call muse_wcs_centroid_stars() and muse_wcs_solve() to find the
+  best detection sigma level for the most accurate astrometric solution. The
+  repeated measurements start with a detection sigma of |aDetSigma| and loop
+  down to the 1.0-sigma level.
+
+  The best solution is identified, as the one that gives the highest value of
+
+    nid / 50. * min(medrms_x) / medrms_x * min(medrms_y) / medrms_y
+
+  where nid is the identified number of stars, 50 is something of a lower limit
+  for the useful number of stars, and medrms_[xy] are the median scatter left
+  in the solution in x and y.
+
+  The final detection sigma value is recorded in the header keyword
+  MUSE_HDR_WCS_DETSIGMA.
+
+  @note This function changes the CPL messaging level and is hence not supposed
+        to be used from parallel code.
+
+  @error{return CPL_ERROR_NULL_INPUT,
+         input WCS object or its cube component are NULL}
+  @error{return CPL_ERROR_DATA_NOT_FOUND,
+         the astrometric detection image is missing from the cube}
+  @error{return CPL_ERROR_ILLEGAL_INPUT, aDetSigma is not negative}
+  @error{return CPL_ERROR_ILLEGAL_INPUT,
+         an unknown centroiding type was requested}
+  @error{return CPL_ERROR_ILLEGAL_INPUT,
+         table of reference coordinates is empty or NULL}
+  @error{return CPL_ERROR_BAD_FILE_FORMAT,
+         table of detected or reference coordinates don't contain the expected columns}
+  @error{return CPL_ERROR_ILLEGAL_INPUT,
+         aRadius and/or aFAccuracy are non-positive}
+  @error{return CPL_ERROR_ILLEGAL_OUTPUT,
+         no objects could be identified at any sigma level}
+  @error{propagate return code of muse_wcs_solve(),
+         the solution with the finally selected detection sigma failed}
+ */
+/*----------------------------------------------------------------------------*/
+cpl_error_code
+muse_wcs_optimize_solution(muse_wcs_object *aWCSObj, float aDetSigma,
+                           muse_wcs_centroid_type aCentroid,
+                           cpl_table *aReference, float aRadius,
+                           float aFAccuracy, int aIter, float aRejSigma)
+{
+  cpl_ensure_code(aWCSObj && aWCSObj->cube, CPL_ERROR_NULL_INPUT);
+  /* check that the cube contains the detection image */
+  cpl_ensure_code(!strncmp(cpl_array_get_string(aWCSObj->cube->recnames, 1),
+                         MUSE_WCS_DETIMAGE_EXTNAME, strlen(MUSE_WCS_DETIMAGE_EXTNAME) + 1),
+                  CPL_ERROR_DATA_NOT_FOUND);
+  cpl_ensure_code(aDetSigma < 0., CPL_ERROR_ILLEGAL_INPUT);
+  switch (aCentroid) {
+  case MUSE_WCS_CENTROID_GAUSSIAN:
+  case MUSE_WCS_CENTROID_MOFFAT:
+  case MUSE_WCS_CENTROID_BOX:
+    break;
+  default:
+    return cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT);
+  }
+  int nref = cpl_table_get_nrow(aReference);
+  cpl_ensure_code(nref > 0, CPL_ERROR_ILLEGAL_INPUT);
+  cpl_ensure_code(muse_cpltable_check(aReference, muse_wcs_reference_def)
+                  == CPL_ERROR_NONE, CPL_ERROR_BAD_FILE_FORMAT);
+  cpl_ensure_code(aRadius > 0.&& aFAccuracy > 0., CPL_ERROR_ILLEGAL_INPUT);
+
+  float detsigma = fabsf(aDetSigma),
+        lolimit = 0.9999; /* 1.0 with a bit of margin */
+  muse_image *detimage = muse_imagelist_get(aWCSObj->cube->recimages, 1);
+
+  /* clear incoming detections and solutions (if any) */
+  cpl_table_delete(aWCSObj->detected);
+  aWCSObj->detected = NULL;
+  cpl_propertylist_delete(aWCSObj->wcs);
+  aWCSObj->wcs = NULL;
+  /* create table that can be used to find the optimal solution afterwards */
+  cpl_table *tres = cpl_table_new(lround((detsigma - lolimit) / 0.1) + 1);
+  cpl_table_new_column(tres, "detsigma", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "detsigma", "%.3f");
+  cpl_table_new_column(tres, "ndet", CPL_TYPE_INT);
+  cpl_table_new_column(tres, "nid", CPL_TYPE_INT);
+  cpl_table_new_column(tres, "scalex", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "scalex", "%.4f");
+  cpl_table_new_column(tres, "scaley", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "scaley", "%.4f");
+  cpl_table_new_column(tres, "anglex", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "anglex", "%.3f");
+  cpl_table_new_column(tres, "angley", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "angley", "%.3f");
+  cpl_table_new_column(tres, "medresx", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "medresx", "%.3f");
+  cpl_table_new_column(tres, "medresy", CPL_TYPE_FLOAT);
+  cpl_table_set_column_format(tres, "medresy", "%.3f");
+
+  /* run detection and solution for all sigma levels between |detsigma| and 1.0 */
+  cpl_error_code rc = CPL_ERROR_NONE;
+  float ds;
+  int irow;
+  for (ds = detsigma, irow = 0; ds > lolimit; ds -= 0.1, irow++) {
+    cpl_msg_debug(__func__, "searching for solution with detection sigma %.3f", ds);
+    cpl_msg_indent_more();
+    /* quieten output from cpl_ppm_match_points(),d muse_wcs_centroid_stars(), *
+     * etc.; we'll get the necessary output at the end with the final run      */
+    cpl_msg_severity level = cpl_msg_get_level();
+    cpl_msg_set_level(CPL_MSG_WARNING);
+
+    /* first, detect stars at this level */
+    aWCSObj->detected = muse_wcs_centroid_stars(detimage, ds, aCentroid);
+    cpl_table_set_float(tres, "detsigma", irow, ds);
+    cpl_table_set_int(tres, "ndet", irow, cpl_table_get_nrow(aWCSObj->detected));
+
+    /* now see, if we identify stars and find a solution */
+    cpl_errorstate state = cpl_errorstate_get();
+    rc = muse_wcs_solve(aWCSObj, aReference, aRadius, aFAccuracy, aIter,
+                        aRejSigma);
+    if (rc == CPL_ERROR_NONE && aWCSObj->wcs) {
+      cpl_table_set_int(tres, "nid", irow,
+                        cpl_propertylist_get_int(aWCSObj->wcs, QC_ASTROMETRY_NSTARS));
+      cpl_table_set_float(tres, "scalex", irow,
+                          cpl_propertylist_get_float(aWCSObj->wcs, QC_ASTROMETRY_SCX));
+      cpl_table_set_float(tres, "scaley", irow,
+                          cpl_propertylist_get_float(aWCSObj->wcs, QC_ASTROMETRY_SCY));
+      cpl_table_set_float(tres, "anglex", irow,
+                          cpl_propertylist_get_float(aWCSObj->wcs, QC_ASTROMETRY_ANGX));
+      cpl_table_set_float(tres, "angley", irow,
+                          cpl_propertylist_get_float(aWCSObj->wcs, QC_ASTROMETRY_ANGY));
+      cpl_table_set_float(tres, "medresx", irow,
+                          cpl_propertylist_get_float(aWCSObj->wcs, QC_ASTROMETRY_RESX));
+      cpl_table_set_float(tres, "medresy", irow,
+                          cpl_propertylist_get_float(aWCSObj->wcs, QC_ASTROMETRY_RESY));
+      cpl_propertylist_delete(aWCSObj->wcs);
+      aWCSObj->wcs = NULL;
+    } else {
+      cpl_errorstate_set(state); /* ignore errors at this point */
+    }
+    cpl_table_delete(aWCSObj->detected);
+    aWCSObj->detected = NULL;
+    cpl_msg_set_level(level);
+    cpl_msg_indent_less();
+  } /* for ds */
+
+  cpl_boolean debug = getenv("MUSE_DEBUG_WCS") && atoi(getenv("MUSE_DEBUG_WCS")) >= 1;
+  if (debug) {
+    printf("%s: full table of results:\n", __func__);
+    cpl_table_dump(tres, 0, 1000, stdout);
+    fflush(stdout);
+  }
+
+  /* reject failed results and those far away from the expected scale */
+  double scale = muse_pfits_get_mode(aWCSObj->cube->header) > MUSE_MODE_WFM_AO_N
+               ? kMuseSpaxelSizeX_NFM : kMuseSpaxelSizeY_WFM;
+  cpl_msg_debug(__func__, "pruning results +/-10%% away from expected spaxel "
+                "scale of %.3f arcsec/pixel", scale);
+  cpl_table_unselect_all(tres);
+  cpl_table_or_selected_float(tres, "scalex", CPL_GREATER_THAN, scale * 1.1);
+  cpl_table_or_selected_float(tres, "scalex", CPL_LESS_THAN, scale * 0.9);
+  cpl_table_or_selected_float(tres, "scaley", CPL_GREATER_THAN, scale * 1.1);
+  cpl_table_or_selected_float(tres, "scaley", CPL_LESS_THAN, scale * 0.9);
+  cpl_table_or_selected_invalid(tres, "nid"); /* any of the result columns ... */
+  cpl_table_erase_selected(tres);
+  if (debug) {
+    printf("%s: pruned table of results:\n", __func__);
+    cpl_table_dump(tres, 0, 1000, stdout);
+    fflush(stdout);
+  }
+  /* check if there are still table rows left */
+  if (cpl_table_get_nrow(tres) < 1) {
+    cpl_table_delete(tres);
+    cpl_msg_error(__func__, "No valid solution found in the range %.3f .. %.3f "
+                  "sigma", detsigma, lolimit);
+    return cpl_error_set(__func__, CPL_ERROR_ILLEGAL_OUTPUT);
+  }
+
+  /* add table column with a weight to evaluate the goodness of each result; *
+   * use                                                                     *
+   *   NID / 50. * min(medresx) / medresx * min(medresy) / medresy           *
+   * as formula to fill it                                                   */
+  cpl_table_cast_column(tres, "nid", "weight", CPL_TYPE_DOUBLE);
+  cpl_table_set_column_format(tres, "weight", "%.5g");
+  cpl_table_divide_scalar(tres, "weight", 50.);
+  cpl_table_divide_columns(tres, "weight", "medresx");
+  cpl_table_multiply_scalar(tres, "weight",
+                            cpl_table_get_column_min(tres, "medresx"));
+  cpl_table_divide_columns(tres, "weight", "medresy");
+  cpl_table_multiply_scalar(tres, "weight",
+                            cpl_table_get_column_min(tres, "medresy"));
+  cpl_propertylist *sort = cpl_propertylist_new();
+  cpl_propertylist_append_bool(sort, "weight", CPL_TRUE);
+  cpl_propertylist_append_bool(sort, "nid", CPL_TRUE);
+  cpl_table_sort(tres, sort);
+  cpl_propertylist_delete(sort);
+  /* the best detection sigma is now the one at the top of the table */
+  detsigma = cpl_table_get_float(tres, "detsigma", 0, NULL);
+  if (debug) {
+    printf("%s: pruned and sorted table of results:\n", __func__);
+    cpl_table_dump(tres, 0, 1000, stdout);
+    printf("%s: ===> use the %.3f-sigma level\n", __func__, detsigma);
+    fflush(stdout);
+  }
+  cpl_table_delete(tres);
+
+  /* so, run detection and solution one last time */
+  aWCSObj->detected = muse_wcs_centroid_stars(detimage, detsigma, aCentroid);
+  rc = muse_wcs_solve(aWCSObj, aReference, aRadius, aFAccuracy, aIter, aRejSigma);
+
+  /* update header with the final value used, for information */
+  if (aWCSObj->wcs) {
+    cpl_propertylist_update_float(aWCSObj->wcs, MUSE_HDR_WCS_DETSIGMA, detsigma);
+    cpl_propertylist_set_comment(aWCSObj->wcs, MUSE_HDR_WCS_DETSIGMA,
+                                 MUSE_HDR_WCS_DETSIGMA_C);
+  }
+
+  return rc;
+} /* muse_wcs_optimize_solution() */
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief   Create FITS headers containing a default (relative) WCS.
@@ -941,8 +1189,6 @@ muse_wcs_create_default(void)
     if (wcslibversion >= 4.23) {
       smallvalue = 0.;
     } /* if newer wcslib */
-    cpl_msg_debug(__func__, "found wcslib %.2f, using smallvalue = %e",
-                  wcslibversion, smallvalue);
   } /* if wcslib string found */
 
   /* axis 1 */
