@@ -310,7 +310,6 @@ muse_xcombine_weights(muse_pixtable **aPixtables, muse_xcombine_types aWeighting
 
 /*----------------------------------------------------------------------------*/
 /**
-  @private
   @brief   Get offsets and scale from table row with matching DATE-OBS entry.
   @param   aOffsets   table with coordinate offsets to apply
   @param   aDateObs   the DATE-OBS string to compare
@@ -319,23 +318,26 @@ muse_xcombine_weights(muse_pixtable **aPixtables, muse_xcombine_types aWeighting
   @note    The returned pointer has to be deallocated with cpl_free() after use.
   @note    By default (if the optional MUSE_OFFSETS_FSCALE column does not
            exist) or on error, the third element of the returned array is NAN, so
-           that no flux scaling occurs.
+           that no flux scaling occurs (when applying the output of this function
+           to a pixel table).
 
-  @error{set CPL_ERROR_NULL_INPUT\, return NULL, aOffsets is NULL}
+  @error{set CPL_ERROR_NULL_INPUT\, return NULL, aOffsets and/or aDateObs are NULL}
   @error{set CPL_ERROR_ILLEGAL_INPUT\, return NULL,
-         aDateObs is NULL or has a length of less than 19 or more than 68 characters}
+         aDateObs has a length of less than 19 or more than 68 characters}
   @error{set NAN for each invalid value\, output a warning,
          the value(s) in the columns MUSE_OFFSETS_DRA and/or MUSE_OFFSETS_DDEC could not be read}
+  @error{no error is raised\, just return NULL,
+         an entry with aDateObs is not found in aOffsets}
  */
 /*----------------------------------------------------------------------------*/
-static double *
+double *
 muse_xcombine_find_offsets(const cpl_table *aOffsets, const char *aDateObs)
 {
   const char *id = "muse_xcombine_tables"; /* pretend to be in that function */
-  cpl_ensure(aOffsets, CPL_ERROR_NULL_INPUT, NULL);
+  cpl_ensure(aOffsets && aDateObs, CPL_ERROR_NULL_INPUT, NULL);
   /* DATE-OBS format allowed by FITS are YYYY-MM-DDThh:mm:ss and optional *
    * fractional seconds that fit within the 68 char FITS limit            */
-  cpl_ensure(aDateObs && strlen(aDateObs) >= 19 && strlen(aDateObs) <= 68,
+  cpl_ensure(strlen(aDateObs) >= 19 && strlen(aDateObs) <= 68,
              CPL_ERROR_ILLEGAL_INPUT, NULL);
 
   int ioff, noff = cpl_table_get_nrow(aOffsets);
