@@ -53,6 +53,8 @@ int
 muse_astrometry_compute(muse_processing *aProcessing,
                         muse_astrometry_params_t *aParams)
 {
+  cpl_errorstate state = cpl_errorstate_get();
+
   muse_postproc_properties *prop = muse_postproc_properties_new(MUSE_POSTPROC_ASTROMETRY);
   /* per-exposure parameters */
   prop->lambdamin = aParams->lambdamin;
@@ -103,6 +105,8 @@ muse_astrometry_compute(muse_processing *aProcessing,
     muse_postproc_properties_delete(prop);
     return -1;
   }
+  muse_processing_append_used(aProcessing, prop->refframe,
+                              CPL_FRAME_GROUP_CALIB, 1);
 
   /* sort input pixel tables into different exposures */
   prop->exposures = muse_processing_sort_exposures(aProcessing);
@@ -132,7 +136,6 @@ muse_astrometry_compute(muse_processing *aProcessing,
 
   /* XXX now combine the possibly more than one astrometric WCSs?! */
 
-  cpl_error_code rc = CPL_ERROR_NONE;
   for (i = 0; i < nexposures; i++) {
     /* convert DQ to NANs, do QC, then save cube; *
      * it already contains the images             */
@@ -146,8 +149,9 @@ muse_astrometry_compute(muse_processing *aProcessing,
                                cpl_propertylist_get_string(wcsobjs[i]->cube->header,
                                                            "OBJECT"));
     cpl_propertylist_update_string(wcsobjs[i]->wcs, "OBJECT", object);
-    rc = muse_processing_save_header(aProcessing, -1, wcsobjs[i]->wcs,
-                                     MUSE_TAG_ASTROMETRY_WCS);
+    cpl_error_code rc = muse_processing_save_header(aProcessing, -1,
+                                                    wcsobjs[i]->wcs,
+                                                    MUSE_TAG_ASTROMETRY_WCS);
     cpl_free(object);
     if (rc != CPL_ERROR_NONE) {
       for ( ; i < nexposures; i++) {
@@ -162,5 +166,5 @@ muse_astrometry_compute(muse_processing *aProcessing,
   }
   cpl_free(wcsobjs);
 
-  return rc == CPL_ERROR_NONE ? 0 : -1;
+  return cpl_errorstate_is_equal(state) ? 0 : -1;
 } /* muse_astrometry_compute() */
