@@ -247,15 +247,10 @@ muse_create_sky_compute(muse_processing *aProcessing,
   muse_image_delete(whitelight);
   muse_mask_delete(sky_mask);
 
-  cpl_table *spectrum = muse_resampling_spectrum(pixtable, aParams->sampling);
-  if (crsigmas > 0.) {
-    cpl_msg_info(__func__, "Recreating sky spectrum with %.3f sigma level CR "
-                 "rejection", crsigmas);
-    muse_sky_mark_cosmic(spectrum, pixtable, crsigmas);
-    cpl_table_delete(spectrum);
-    spectrum = muse_resampling_spectrum(pixtable, aParams->sampling);
-  } /* if crsigmas positive */
-
+  /* Apply mask and create spectrum, possibly with one CR-reject iteration */
+  cpl_table *spectrum = muse_resampling_spectrum_iterate(pixtable,
+                                                         aParams->sampling,
+                                                         0., crsigmas, 1);
   if (spectrum == NULL) {
     muse_pixtable_delete(pixtable);
     return -1;
@@ -263,7 +258,6 @@ muse_create_sky_compute(muse_processing *aProcessing,
   muse_processing_save_table(aProcessing, -1, spectrum, pixtable->header,
                              MUSE_TAG_SKY_SPECTRUM, MUSE_TABLE_TYPE_CPL);
 
-
   cpl_table *lines = muse_sky_lines_load(aProcessing);
   if (lines != NULL) {
     double lambda_low = cpl_table_get_column_min(spectrum, "lambda");
