@@ -228,7 +228,7 @@ muse_fov_load(const char *aFilename)
   if (extension > 0) {
     cpl_errorstate status = cpl_errorstate_get();
     image->stat = cpl_image_load(aFilename, CPL_TYPE_INT, 0, extension);
-    if (cpl_errorstate_get() != status) {
+    if (!cpl_errorstate_is_equal(status)) {
       if (cpl_error_get_code() == CPL_ERROR_DATA_NOT_FOUND) {
         cpl_errorstate_set(status);
         cpl_msg_debug(__func__, "Ignoring empty extension %s in \"%s\"",
@@ -257,7 +257,7 @@ muse_fov_load(const char *aFilename)
   if (extension > 0) {
     cpl_errorstate status = cpl_errorstate_get();
     image->dq = cpl_image_load(aFilename, CPL_TYPE_INT, 0, extension);
-    if (cpl_errorstate_get() != status) {
+    if (!cpl_errorstate_is_equal(status)) {
       cpl_errorstate_set(status);
       cpl_error_set_message(__func__, MUSE_ERROR_READ_DQ, "Could not load "
                             "extension %s from \"%s\"", EXTNAME_DQ, aFilename);
@@ -463,7 +463,7 @@ muse_align_celestial_from_pixel(cpl_table *aTable,
   }
   cpl_free(wcs);
 
-  if (cpl_errorstate_get() != status) {
+  if (!cpl_errorstate_is_equal(status)) {
     return -1;
   }
   return 0;
