@@ -42,7 +42,8 @@
   @param    aHeader   the header to modify
 
   Select all bright (flux > 1000 count) spots with valid FWHM values in each
-  image of the series and add simple FWHM statistics for them.
+  image of the series and add simple FWHM statistics for them. Also add mean
+  and standard deviation of all average FWHM values across all exposures.
  */
 /*---------------------------------------------------------------------------*/
 static void
@@ -51,11 +52,14 @@ muse_geometry_qc_spots(cpl_table *aSpots, cpl_propertylist *aHeader)
   if (!aSpots || !aHeader) {
     return;
   }
-  cpl_msg_debug(__func__, "Adding QC keywords to %s", MUSE_TAG_SPOTS_TABLE);
 
   unsigned int nexp,
                nexp1 = cpl_table_get_column_min(aSpots, "image"),
                nexp2 = cpl_table_get_column_max(aSpots, "image");
+  cpl_msg_debug(__func__, "Adding QC keywords for %u exposures to %s",
+                nexp2 - nexp1 + 1, MUSE_TAG_SPOTS_TABLE);
+
+  cpl_array *amean = cpl_array_new(nexp2 - nexp1 + 1, CPL_TYPE_DOUBLE);
   for (nexp = nexp1; nexp <= nexp2; nexp++) {
     cpl_table_unselect_all(aSpots);
     cpl_table_or_selected_int(aSpots, "image", CPL_EQUAL_TO, nexp);
@@ -79,7 +83,14 @@ muse_geometry_qc_spots(cpl_table *aSpots, cpl_propertylist *aHeader)
     cpl_propertylist_update_float(aHeader, keyword, median);
     snprintf(keyword, KEYWORD_LENGTH, QC_GEO_EXPk_STDEV, nexp);
     cpl_propertylist_update_float(aHeader, keyword, stdev);
+
+    cpl_array_set_double(amean, nexp - nexp1, mean);
   } /* for nexp */
+  cpl_propertylist_update_float(aHeader, QC_GEO_FWHM_MEAN,
+                                cpl_array_get_mean(amean));
+  cpl_propertylist_update_float(aHeader, QC_GEO_FWHM_STDEV,
+                                cpl_array_get_stdev(amean));
+  cpl_array_delete(amean);
 } /* muse_geometry_qc_spots() */
 
 /*---------------------------------------------------------------------------*/
@@ -88,6 +99,10 @@ muse_geometry_qc_spots(cpl_table *aSpots, cpl_propertylist *aHeader)
   @param    aGeoInit   the output geometry table
   @param    aHeader    the header to modify
   @param    aLambdas   vector with the wavelengths used
+
+  The angle computed from the table at this stage is inverted by default, unless
+  the environment variable MUSE_GEOMETRY_NO_INVERSION is set to a positive
+  integer.
  */
 /*---------------------------------------------------------------------------*/
 static void
@@ -99,9 +114,16 @@ muse_geometry_qc_ifu(muse_geo_table *aGeoInit, cpl_propertylist *aHeader,
   }
   cpl_table *gtinit = aGeoInit->table;
   const unsigned char ifu = cpl_table_get_int(gtinit, MUSE_GEOTABLE_FIELD, 0, NULL);
-  double angle = cpl_table_get_column_mean(gtinit, MUSE_GEOTABLE_ANGLE),
+  /* normally flip the angles here */
+  double angle = -cpl_table_get_column_mean(gtinit, MUSE_GEOTABLE_ANGLE),
          astdev = cpl_table_get_column_stdev(gtinit, MUSE_GEOTABLE_ANGLE),
-         amedian = cpl_table_get_column_median(gtinit, MUSE_GEOTABLE_ANGLE);
+         amedian = -cpl_table_get_column_median(gtinit, MUSE_GEOTABLE_ANGLE);
+  /* if the geometry table later is /not/ flipped, flip mean/median back */
+  if (getenv("MUSE_GEOMETRY_NO_INVERSION")
+      && atoi(getenv("MUSE_GEOMETRY_NO_INVERSION")) > 0) {
+    angle *= -1.;
+    amedian *= -1.;
+  }
   cpl_msg_debug(__func__, "Adding QC keywords for IFU %hhu: angle = %.3f +/- %.3f "
                 "(%.3f) deg", ifu, angle, astdev, amedian);
   char *keyword = cpl_sprintf(QC_GEO_IFUi_ANGLE, ifu);
@@ -140,28 +162,6 @@ muse_geometry_qc_ifu(muse_geo_table *aGeoInit, cpl_propertylist *aHeader,
   } /* for i (all lambdas) */
 } /* muse_geometry_qc_ifu() */
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    Add the global QC parameters to the geometry table.
-  @param    aGeoTable   the output geometry table
-  @param    aHeader     the header to modify
- */
-/*---------------------------------------------------------------------------*/
-static void
-muse_geometry_qc_global(const muse_geo_table *aGeoTable,
-                        cpl_propertylist *aHeader)
-{
-  if (!aGeoTable || !aHeader) {
-    return;
-  }
-  double angle = cpl_table_get_column_mean(aGeoTable->table, MUSE_GEOTABLE_ANGLE),
-         astdev = cpl_table_get_column_stdev(aGeoTable->table, MUSE_GEOTABLE_ANGLE),
-         amedian = cpl_table_get_column_median(aGeoTable->table, MUSE_GEOTABLE_ANGLE);
-  cpl_msg_debug(__func__, "Adding global QC keywords: angle = %.3f +/- %.3f "
-                "(%.3f) deg", angle, astdev, amedian);
-  cpl_propertylist_update_float(aHeader, QC_GEO_MASK_ANGLE, amedian);
-} /* muse_geometry_qc_global() */
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    Load and pre-process the raw images (or skip loading them).
@@ -307,20 +307,35 @@ muse_geometry_reconstruct_combined(muse_processing *aProcessing,
     cpl_table_delete(trace);
     cpl_table_delete(wavecal);
     muse_image_delete(combined);
+    if (!pts[nifu - 1]) {
+      cpl_msg_warning(__func__, "Could not create a pixel table for reconstruction"
+                      " for IFU %2hhu!", nifu++);
+    }
   } /* for nifu (all IFUs) */
-  muse_pixtable *pt = pts[aParams->ifu1 - 1];
+
   /* merge all pixel tables                                               *
    * a la muse_pixtable_load_merge_channels() but without flux correction */
-  for (nifu = (unsigned)aParams->ifu1 + 1; nifu <= (unsigned)aParams->ifu2; nifu++) {
-    if (pts[nifu - 1]) {
-      cpl_table_insert(pt->table, pts[nifu - 1]->table, muse_pixtable_get_nrow(pt));
-      muse_pixtable_delete(pts[nifu - 1]);
-    } /* if */
-  } /* for nifu (all IFUs) */
-  /* cut the cube, for faster reconstruction speed */
+  nifu = aParams->ifu1;
+  muse_pixtable *pt = pts[nifu - 1];
+  pts[nifu - 1] = NULL; /* to not free it too early */
+  while (!pt && nifu <= aParams->ifu2) { /* in case we picked a non-existing table */
+    nifu++;
+    pt = pts[nifu - 1];
+    pts[nifu - 1] = NULL; /* to not free it too early */
+  } /* while */
+  if (pt) {
+    for ( ; nifu <= (unsigned)aParams->ifu2; nifu++) {
+      if (pts[nifu - 1]) {
+        cpl_table_insert(pt->table, pts[nifu - 1]->table, muse_pixtable_get_nrow(pt));
+        muse_pixtable_delete(pts[nifu - 1]);
+      } /* if */
+    } /* for nifu (all IFUs) */
+  } /* if pt */
   cpl_free(pts);
+
+  /* cut the cube, for faster reconstruction speed */
   muse_pixtable_restrict_wavelength(pt, aLMin, aLMax);
-  if (muse_pixtable_get_nrow(pt) < 1) {
+  if (muse_pixtable_get_nrow(pt) < 1) { /* will also cause return for NULL pt */
     muse_pixtable_delete(pt);
     return cpl_error_set_message(__func__, CPL_ERROR_ILLEGAL_OUTPUT,
                                  "After cutting to %.2f..%.2f in wavelength no "
@@ -481,18 +496,33 @@ muse_geometry_reconstruct(muse_processing *aProcessing,
       cpl_table_delete(trace);
       cpl_table_delete(wavecal);
       muse_image_delete(image);
+      if (!pts[nifu - 1]) {
+        cpl_msg_warning(__func__, "Could not create a pixel table for "
+                        "reconstruction for IFU %2hhu!", nifu++);
+      }
     } /* for nifu (all IFUs) */
-    muse_pixtable *pt = pts[aParams->ifu1 - 1];
+
     /* merge all pixel tables                                               *
      * a la muse_pixtable_load_merge_channels() but without flux correction */
-    for (nifu = (unsigned)aParams->ifu1 + 1; nifu <= (unsigned)aParams->ifu2; nifu++) {
-      if (pts[nifu - 1]) {
-        cpl_table_insert(pt->table, pts[nifu - 1]->table, muse_pixtable_get_nrow(pt));
-        muse_pixtable_delete(pts[nifu - 1]);
-      } /* if */
-    } /* for nifu (all IFUs) */
-    /* cut the cube, for faster reconstruction speed */
+    nifu = aParams->ifu1;
+    muse_pixtable *pt = pts[nifu - 1];
+    pts[nifu - 1] = NULL; /* to not free it too early */
+    while (!pt && nifu <= aParams->ifu2) { /* in case we picked a non-existing table */
+      nifu++;
+      pt = pts[nifu - 1];
+      pts[nifu - 1] = NULL; /* to not free it too early */
+    } /* while */
+    if (pt) {
+      for ( ; nifu <= (unsigned)aParams->ifu2; nifu++) {
+        if (pts[nifu - 1]) {
+          cpl_table_insert(pt->table, pts[nifu - 1]->table, muse_pixtable_get_nrow(pt));
+          muse_pixtable_delete(pts[nifu - 1]);
+        } /* if */
+      } /* for nifu (all IFUs) */
+    } /* if pt */
     cpl_free(pts);
+
+    /* cut the cube, for faster reconstruction speed */
     muse_pixtable_restrict_wavelength(pt, aLMin, aLMax);
     if (muse_pixtable_get_nrow(pt) < 1) {
       cpl_error_set_message(__func__, CPL_ERROR_ILLEGAL_OUTPUT,
@@ -743,11 +773,11 @@ muse_geometry_compute(muse_processing *aProcessing,
   if (result < rcfinal) {
     result = rcfinal;
   }
-  muse_geometry_qc_global(geofinal, headfinal);
   /* smooth the result per slicer stack, if sigma > 0. */
   if (aParams->smooth > 0.) {
     /* save this state already */
     if (geofinal) {
+      muse_geo_qc_global(geofinal, headfinal);
       muse_processing_save_table(aProcessing, -1, geofinal->table, headfinal,
                                  MUSE_TAG_GEOMETRY_OLD, MUSE_TABLE_TYPE_CPL);
     }
@@ -764,6 +794,8 @@ muse_geometry_compute(muse_processing *aProcessing,
   }
   /* now this is the really final table that we want to save */
   if (geofinal) {
+    /* compute (or update) the global QC parameters */
+    muse_geo_qc_global(geofinal, headfinal);
     muse_processing_save_table(aProcessing, -1, geofinal->table, headfinal,
                                MUSE_TAG_GEOMETRY_TABLE, MUSE_TABLE_TYPE_CPL);
   }
