@@ -285,7 +285,7 @@ muse_lingain_sort_images(const muse_imagelist *aList)
   cpl_table_sort(exposures, order);
   cpl_propertylist_delete(order);
 
-  if (cpl_errorstate_get() != status) {
+  if (!cpl_errorstate_is_equal(status)) {
     cpl_table_delete(exposures);
     return NULL;
   }
@@ -428,7 +428,7 @@ muse_lingain_create_windowlist(const cpl_table *aTrace,
     cpl_free(qwindow);
   }
 
-  if (cpl_errorstate_get() != status) {
+  if (!cpl_errorstate_is_equal(status)) {
     cpl_table_delete(windowlist);
     return NULL;
   }
@@ -655,7 +655,7 @@ muse_lingain_window_get_gain(const cpl_table *aWindowList,
   cpl_table_new_column_array(gain, "Variance", CPL_TYPE_DOUBLE, nwindows);
   cpl_table_new_column_array(gain, "Gain", CPL_TYPE_DOUBLE, nwindows);
 
-  if (cpl_errorstate_get() != state) {
+  if (!cpl_errorstate_is_equal(state)) {
     cpl_table_delete(gain);
     cpl_table_delete(flats);
     return NULL;
