@@ -111,25 +111,22 @@ muse_lsf_subtract_arcs(muse_lsf_cube *aLsfCube, cpl_table *aPixtable) {
 /**
    @brief Create a header with the QC parameters for the LSF.
    @param aLsfCube    Computed LSF cube
-   @param aIFU        the IFU/channel number
    @retval CPL_ERROR_NONE if ererything is OK,
    @cpl_ensure_code{aLsfCube, CPL_ERROR_NULL_INPUT}
-   @cpl_ensure_code{aIFU > 0, CPL_ERROR_ILLEGAL_INPUT}
 
    This function calculates for each slice the following parameters:
 
-    - LSF IFUm SLICEj FWHM MEAN: Mean FWHM of the LSF slice j
-    - LSF IFUm SLICEj FWHM STDEV: Standard deviation of the LSF in slice j
-    - LSF IFUm SLICEj FWHM MIN: Minimum FWHM of the LSF in slice j
-    - LSF IFUm SLICEj FWHM MAX: Maximum FWHM of the LSF in slice j
+    - LSF SLICEj FWHM MEAN: Mean FWHM of the LSF slice j
+    - LSF SLICEj FWHM STDEV: Standard deviation of the LSF in slice j
+    - LSF SLICEj FWHM MIN: Minimum FWHM of the LSF in slice j
+    - LSF SLICEj FWHM MAX: Maximum FWHM of the LSF in slice j
 
    They are added to the given header.
  */
 static cpl_error_code
-muse_lsf_qc(muse_lsf_cube *aLsfCube, int aIFU)
+muse_lsf_qc(muse_lsf_cube *aLsfCube)
 {
   cpl_ensure_code(aLsfCube, CPL_ERROR_NULL_INPUT);
-  cpl_ensure_code(aIFU > 0, CPL_ERROR_ILLEGAL_INPUT);
 
   cpl_size i_slice, n_slices = cpl_imagelist_get_size(aLsfCube->img);
   for (i_slice = 0; i_slice < n_slices; i_slice++) {
@@ -165,17 +162,17 @@ muse_lsf_qc(muse_lsf_cube *aLsfCube, int aIFU)
       cpl_array_set(fwhm, i_lambda, f);
     }
     char keyword[KEYWORD_LENGTH];
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM MEAN",
-             aIFU, (int)i_slice+1);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM MEAN",
+             (int)i_slice+1);
     cpl_propertylist_append_float(aLsfCube->header, keyword, cpl_array_get_mean(fwhm));
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM STDEV",
-             aIFU, (int)i_slice+1);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM STDEV",
+             (int)i_slice+1);
     cpl_propertylist_append_float(aLsfCube->header, keyword, cpl_array_get_stdev(fwhm));
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM MIN",
-             aIFU, (int)i_slice+1);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM MIN",
+             (int)i_slice+1);
     cpl_propertylist_append_float(aLsfCube->header, keyword, cpl_array_get_min(fwhm));
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM MAX",
-             aIFU, (int)i_slice+1);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM MAX",
+             (int)i_slice+1);
     cpl_propertylist_append_float(aLsfCube->header, keyword, cpl_array_get_max(fwhm));
     cpl_array_delete(fwhm);
   }
@@ -244,17 +241,17 @@ muse_lsf_params_qc(cpl_propertylist *aHeader, const muse_lsf_params **aSlicePars
       cpl_array_set(fwhm, i_lambda, f);
     }
     char keyword[KEYWORD_LENGTH];
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM MEAN",
-             (*det)->ifu, (int)(*det)->slice);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM MEAN",
+             (int)(*det)->slice);
     cpl_propertylist_append_float(aHeader, keyword, cpl_array_get_mean(fwhm));
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM STDEV",
-             (*det)->ifu, (int)(*det)->slice);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM STDEV",
+             (int)(*det)->slice);
     cpl_propertylist_append_float(aHeader, keyword, cpl_array_get_stdev(fwhm));
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM MIN",
-             (*det)->ifu, (int)(*det)->slice);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM MIN",
+             (int)(*det)->slice);
     cpl_propertylist_append_float(aHeader, keyword, cpl_array_get_min(fwhm));
-    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF IFU%i SLICE%i FWHM MAX",
-             (*det)->ifu, (int)(*det)->slice);
+    snprintf(keyword, KEYWORD_LENGTH, "ESO QC LSF SLICE%i FWHM MAX",
+             (int)(*det)->slice);
     cpl_propertylist_append_float(aHeader, keyword, cpl_array_get_max(fwhm));
     cpl_array_delete(fwhm);
   }
@@ -360,7 +357,7 @@ muse_lsf_compute(muse_processing *aProcessing, muse_lsf_params_t *aParams)
     }
 
     /* add QC parameters to the primary header of the LSF cube and save it */
-    muse_lsf_qc(lsfcube, aParams->nifu);
+    muse_lsf_qc(lsfcube);
     muse_processing_save_cube(aProcessing, aParams->nifu, lsfcube,
                               MUSE_TAG_LSF_PROFILE, MUSE_CUBE_TYPE_LSF);
     if (aParams->save_subtracted) {
