@@ -39,10 +39,9 @@
 /**
   @brief    Apply spatial offsets and flux scale to a pixel table (of a single
             exposure)
-  @param    aPT   the pixel table to be adapted
-
-  This function reacts to the environment variables MUSE_SCIPOST_RA_OFFSET and
-  MUSE_SCIPOST_DEC_OFFSET as well as MUSE_SCIPOST_FLUX_SCALE.
+  @param    aPT        the pixel table to be adapted
+  @param    aOffsets   the table with offsets and scalings to apply
+  @param    aPurpose   some words about the purpose, just for info-level output
 
   Their interpretation is copied from muse_xcombine_tables(), but only the first
   value in these variables is interpreted as offset (in deg) and flux scaling
@@ -50,60 +49,71 @@
  */
 /*----------------------------------------------------------------------------*/
 static void
-muse_scipost_offsets_scale(muse_pixtable *aPT)
+muse_scipost_offsets_scale(muse_pixtable *aPT, const cpl_table *aOffsets,
+                           const char *aPurpose)
 {
-  if (!aPT) {
+  if (!aPT || !aOffsets) {
     return;
   }
   if (!aPT->header) {
     return;
   }
-  char *raenv = getenv("MUSE_SCIPOST_RA_OFFSET"),
-       *decenv = getenv("MUSE_SCIPOST_DEC_OFFSET"),
-       *fscaleenv = getenv("MUSE_SCIPOST_FLUX_SCALE");
-  if (!raenv && !decenv && !fscaleenv) {
-    return;
-  }
+  cpl_msg_info(__func__, "Applying offsets to %s...", aPurpose);
+  cpl_msg_indent_more();
   double ra =  muse_pfits_get_ra(aPT->header),
-         dec = muse_pfits_get_dec(aPT->header);
+         dec = muse_pfits_get_dec(aPT->header),
+         *offsets = muse_xcombine_find_offsets(aOffsets,
+                                               muse_pfits_get_dateobs(aPT->header));
   char keyword[KEYWORD_LENGTH], comment[KEYWORD_LENGTH];
-  if (raenv) {
-    double raoff = atof(raenv);
-    cpl_msg_info(__func__, "Applying offset %g deg to RA.", raoff);
-    ra -= raoff;
-    /* store in the header of the pixel table */
-    cpl_propertylist_update_double(aPT->header, "RA", ra);
-    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1);
-    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA_C, raoff * 3600.);
-    cpl_propertylist_append_double(aPT->header, keyword, raoff);
+  if (offsets) {
+    if (isfinite(offsets[0]) && isfinite(offsets[1])) {
+      ra -= offsets[0];
+      dec -= offsets[1];
+      cpl_msg_debug(__func__, "Applying coordinate offsets to exposure: %e/%e"
+                    " deg", offsets[0], offsets[1]);
+      /* update RA/DEC in the header of the pixel table */
+      cpl_errorstate state = cpl_errorstate_get();
+      cpl_propertylist_update_double(aPT->header, "RA", ra);
+      if (!cpl_errorstate_is_equal(state)) {
+        cpl_errorstate_set(state);
+        cpl_propertylist_update_float(aPT->header, "RA", ra);
+      }
+      cpl_propertylist_set_comment(aPT->header, "RA", "offset applied!");
+      state = cpl_errorstate_get();
+      cpl_propertylist_update_double(aPT->header, "DEC", dec);
+      if (!cpl_errorstate_is_equal(state)) {
+        cpl_errorstate_set(state);
+        cpl_propertylist_update_float(aPT->header, "DEC", dec);
+      }
+      cpl_propertylist_set_comment(aPT->header, "DEC", "offset applied!");
+      /* store in the header of the pixel table */
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA, 1);
+      snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DRA_C, offsets[0] * 3600.);
+      cpl_propertylist_append_double(aPT->header, keyword, offsets[0]);
+      cpl_propertylist_set_comment(aPT->header, keyword, comment);
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1);
+      snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC_C, offsets[1] * 3600.);
+      cpl_propertylist_append_double(aPT->header, keyword, offsets[1]);
+      cpl_propertylist_set_comment(aPT->header, keyword, comment);
+    } /* if spatial offsets */
+    if (isnormal(offsets[2])) { /* valid flux scale */
+      /* get and apply the scale */
+      cpl_msg_debug(__func__, "Scaling flux of exposure by %g.", offsets[2]);
+      muse_pixtable_flux_multiply(aPT, offsets[2]);
+      /* store in the header of the pixel table */
+      snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1);
+      cpl_propertylist_append_double(aPT->header, keyword, offsets[2]);
+      cpl_propertylist_set_comment(aPT->header, keyword, MUSE_HDR_FLUX_SCALEi_C);
+    } /* if scale */
+    /* store date of changed exposure in the header of the output pixel table */
+    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1);
+    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1);
+    cpl_propertylist_append_string(aPT->header, keyword,
+                                   muse_pfits_get_dateobs(aPT->header));
     cpl_propertylist_set_comment(aPT->header, keyword, comment);
-  }
-  if (decenv) {
-    double decoff = atof(decenv);
-    cpl_msg_info(__func__, "Applying offset %g deg to DEC.", decoff);
-    dec -= decoff;
-    /* store in the header of the pixel table */
-    cpl_propertylist_update_double(aPT->header, "DEC", dec);
-    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC, 1);
-    snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DDEC_C, decoff * 3600.);
-    cpl_propertylist_append_double(aPT->header, keyword, decoff);
-    cpl_propertylist_set_comment(aPT->header, keyword, comment);
-  }
-  if (fscaleenv) {
-    /* get and apply the scale */
-    double fscale = atof(fscaleenv);
-    cpl_msg_debug(__func__, "Scaling flux of exposure by %g.", fscale);
-    muse_pixtable_flux_multiply(aPT, fscale);
-    /* store in the header of the output pixel table */
-    snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_FLUX_SCALEi, 1);
-    cpl_propertylist_append_double(aPT->header, keyword, fscale);
-    cpl_propertylist_set_comment(aPT->header, keyword, MUSE_HDR_FLUX_SCALEi_C);
-  }
-  /* store in the header of the pixel table */
-  snprintf(keyword, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS, 1);
-  snprintf(comment, KEYWORD_LENGTH, MUSE_HDR_OFFSETi_DATEOBS_C, 1);
-  cpl_propertylist_append_string(aPT->header, keyword,
-                                 muse_pfits_get_dateobs(aPT->header));
+  } /* if offsets */
+  cpl_free(offsets);
+  cpl_msg_indent_less();
 } /* muse_scipost_offsets_scale() */
 
 /*----------------------------------------------------------------------------*/
@@ -166,7 +176,6 @@ muse_scipost_compute(muse_processing *aProcessing,
     { MUSE_SCIPOST_PARAM_SKYMETHOD_SUBTRACT_MODEL, MUSE_POSTPROC_SKYMETHOD_NONE }, /* sic! */
     { MUSE_SCIPOST_PARAM_SKYMETHOD_MODEL, MUSE_POSTPROC_SKYMETHOD_MODEL },
     { MUSE_SCIPOST_PARAM_SKYMETHOD_SIMPLE, MUSE_POSTPROC_SKYMETHOD_SIMPLE },
-    /* { MUSE_SCIPOST_PARAM_SKYMETHOD_ROW_BY_ROW, MUSE_POSTPROC_SKYMETHOD_ROWBYROW }, */
     { MUSE_SCIPOST_PARAM_SKYMETHOD_INVALID_VALUE, MUSE_POSTPROC_SKYMETHOD_MODEL },
   };
   prop->skymethod = MUSE_POSTPROC_SKYMETHOD_MODEL;
@@ -324,9 +333,12 @@ muse_scipost_compute(muse_processing *aProcessing,
       /* duplicate table to not mess with the coordinates in the individual *
        * pixel tables, which are still needed when combining the exposures  */
       muse_pixtable *pt = muse_pixtable_duplicate(pixtables[i]);
-      double ra = muse_pfits_get_ra(pt->header),
-             dec = muse_pfits_get_dec(pt->header);
-      muse_wcs_position_celestial(pt, ra, dec);
+      /* since after positioning it is too late to *
+       * adapt the reference position, do it now   */
+      muse_scipost_offsets_scale(pt, offsets,
+                                 "positioned pixel table for saving");
+      muse_wcs_position_celestial(pt, muse_pfits_get_ra(pt->header),
+                                  muse_pfits_get_dec(pt->header));
       muse_processing_save_table(aProcessing, -1, pt, NULL,
                                  MUSE_TAG_PIXTABLE_POSITIONED,
                                  MUSE_TABLE_TYPE_PIXTABLE);
@@ -364,7 +376,11 @@ muse_scipost_compute(muse_processing *aProcessing,
     }
   } else {
     bigpixtable = pixtables[0];
-    muse_scipost_offsets_scale(bigpixtable);
+    /* if there is only one pixel table, apply the offset for that */
+    cpl_msg_indent_more();
+    muse_scipost_offsets_scale(bigpixtable, offsets,
+                               "single pixel table for resampling");
+    cpl_msg_indent_less();
     muse_wcs_position_celestial(bigpixtable,
                                 muse_pfits_get_ra(bigpixtable->header),
                                 muse_pfits_get_dec(bigpixtable->header));
