@@ -53,6 +53,8 @@ int
 muse_standard_compute(muse_processing *aProcessing,
                       muse_standard_params_t *aParams)
 {
+  cpl_errorstate state = cpl_errorstate_get();
+
   muse_postproc_properties *prop = muse_postproc_properties_new(MUSE_POSTPROC_STANDARD);
   /* per-exposure parameters */
   prop->lambdamin = aParams->lambdamin;
@@ -88,6 +90,8 @@ muse_standard_compute(muse_processing *aProcessing,
     muse_postproc_properties_delete(prop);
     return -1;
   }
+  muse_processing_append_used(aProcessing, prop->refframe,
+                              CPL_FRAME_GROUP_CALIB, 1);
   prop->select = MUSE_FLUX_SELECT_BRIGHTEST;
   if (aParams->select == MUSE_STANDARD_PARAM_SELECT_DISTANCE) {
     prop->select = MUSE_FLUX_SELECT_NEAREST;
@@ -142,7 +146,6 @@ muse_standard_compute(muse_processing *aProcessing,
 
   /* XXX now combine the possibly more than one response tables */
 
-  cpl_error_code rc = CPL_ERROR_NONE;
   cpl_array *filters = muse_cplarray_new_from_delimited_string(aParams->filter,
                                                                ",");
   for (i = 0; i < nexposures; i++) {
@@ -180,8 +183,11 @@ muse_standard_compute(muse_processing *aProcessing,
     char *objorig = cpl_strdup(cpl_propertylist_get_string(header, "OBJECT"));
     char *object = cpl_sprintf("Response curve (%s)", objorig);
     cpl_propertylist_update_string(header, "OBJECT", object);
-    rc = muse_processing_save_table(aProcessing, -1, fluxobjs[i]->response, header,
-                                    MUSE_TAG_STD_RESPONSE, MUSE_TABLE_TYPE_CPL);
+    cpl_error_code rc = rc = muse_processing_save_table(aProcessing, -1,
+                                                        fluxobjs[i]->response,
+                                                        header,
+                                                        MUSE_TAG_STD_RESPONSE,
+                                                        MUSE_TABLE_TYPE_CPL);
     cpl_free(object);
     if (rc != CPL_ERROR_NONE) {
       cpl_free(objorig);
@@ -209,5 +215,5 @@ muse_standard_compute(muse_processing *aProcessing,
   cpl_array_delete(filters);
   cpl_free(fluxobjs);
 
-  return rc == CPL_ERROR_NONE ? 0 : -1;
+  return cpl_errorstate_is_equal(state) ? 0 : -1;
 } /* muse_standard_compute() */
