@@ -175,7 +175,7 @@ muse_test_flux_integrate_from_cube(int argc, char **argv)
        *inref = NULL,
        *inext = NULL;
   muse_flux_profile_type profile = MUSE_FLUX_PROFILE_MOFFAT;
-  muse_flux_selection_type select = MUSE_FLUX_SELECT_BRIGHTEST;
+  muse_flux_selection_type select = MUSE_FLUX_SELECT_NEAREST;
   muse_flux_smooth_type smooth = MUSE_FLUX_SMOOTH_PPOLY;
 
   /* argument processing */
@@ -246,6 +246,10 @@ muse_test_flux_integrate_from_cube(int argc, char **argv)
   /* copy stuff from muse_flux_integrate_std() */
   int nplane = cpl_imagelist_get_size(cube->data) / 2; /* central plane */
   cpl_image *cim = cpl_imagelist_get(cube->data, nplane);
+  /* make sure to reject bad pixels before using object detection      *
+   * using image statistics; different from muse_flux_integrate_std(), *
+   * here we need to use NANs for that, since the saved-and-reloaded   *
+   * cubes do not have a DQ component                                  */
   cpl_image_reject_value(cim, CPL_VALUE_NAN); /* mark NANs */
   double dsigmas[] = { 50., 30., 10., 5. };
   cpl_vector *vsigmas = cpl_vector_wrap(sizeof(dsigmas) / sizeof(double),
@@ -257,15 +261,16 @@ muse_test_flux_integrate_from_cube(int argc, char **argv)
     double med_dist,
            median = cpl_image_get_median_dev(cim, &med_dist),
            threshold = median + 5. * med_dist;
-    cpl_msg_debug(__func__, "failed: %f +/- %f --> %f", median, med_dist,
-                  threshold);
+    cpl_msg_debug(__func__, "failed: %f +/- %f --> %f on plane %d", median,
+                  med_dist, threshold, nplane + 1);
     cpl_vector_unwrap(vsigmas);
     cpl_apertures_delete(apertures);
     muse_datacube_delete(cube);
     PRINT_USAGE(11);
   }
-  cpl_msg_debug(__func__, "The %.1f sigma threshold was used to find %d source%s",
-                cpl_vector_get(vsigmas, isigma), napertures, napertures == 1 ? "" : "s");
+  cpl_msg_debug(__func__, "The %.1f sigma threshold was used to find %d source%s"
+                " on plane %d", cpl_vector_get(vsigmas, isigma), napertures,
+                napertures == 1 ? "" : "s", nplane + 1);
   cpl_vector_unwrap(vsigmas);
   /* now do the flux integration and save the resulting file */
   muse_image *intimage = muse_flux_integrate_cube(cube, apertures, profile);
