@@ -28,7 +28,7 @@
 /* accuracy limits for xsc, ysc, xang, yang recovered from INM test data */
 const double klimitsINM[][4] = {
   { 5.3e-8, 2.3e-8, 0.012, 0.020 }, /* for Gaussian */
-  { 4.1e-8, 2.9e-8, 0.002, 0.009 }, /* for Moffat */
+  { 4.8e-8, 2.9e-8, 0.009, 0.009 }, /* for Moffat */
   { 4.8e-8, 2.4e-8, 0.001, 0.020 }  /* for Box */
 };
 const double kLimitPos = 0.05; /* [pix] object position detection accuracy */
@@ -241,7 +241,7 @@ muse_test_wcs_calibrate_from_cube(int argc, char **argv)
   char *incube = NULL,
        *intable = NULL;
   muse_wcs_centroid_type centroid = MUSE_WCS_CENTROID_MOFFAT;
-  double detsigma = 3.0,
+  double detsigma = -3.0,
          radius = 5.,
          faccuracy = 5.,
          rejsigma = 3.,
@@ -402,7 +402,7 @@ muse_test_wcs_calibrate_from_cube(int argc, char **argv)
   wcs->crpix2 = crpix2;
   wcs->ra = muse_pfits_get_ra(cube->header);
   wcs->dec = muse_pfits_get_dec(cube->header);
-  wcs->detected = muse_wcs_centroid_stars(detimage, detsigma, centroid);
+  wcs->detected = muse_wcs_centroid_stars(detimage, fabsf(detsigma), centroid);
   if (!reftable) {
     muse_datacube_delete(cube);
     muse_wcs_object_delete(wcs);
@@ -412,7 +412,16 @@ muse_test_wcs_calibrate_from_cube(int argc, char **argv)
     PRINT_USAGE(11);
   }
   /* use defaults from the muse_astrometry recipe */
-  muse_wcs_solve(wcs, reftable, radius, faccuracy, niter, rejsigma);
+  if (detsigma < 0.) {
+    cpl_msg_debug(__func__, "optimize %.3f", detsigma);
+    wcs->cube = cube;
+    muse_wcs_optimize_solution(wcs, detsigma, centroid, reftable, radius,
+                               faccuracy, niter, rejsigma);
+    wcs->cube = NULL; /* delete it separately */
+  } else {
+    cpl_msg_debug(__func__, "solve %.3f", detsigma);
+    muse_wcs_solve(wcs, reftable, radius, faccuracy, niter, rejsigma);
+  }
 
   /* prepare input filename for creation of output names */
   char *dot = strrchr(incube, '.');
@@ -461,6 +470,7 @@ muse_test_wcs_calibrate_from_cube(int argc, char **argv)
     muse_wcs_centroid_stars
     muse_wcs_locate_sources
     muse_wcs_solve
+    muse_wcs_optimize_solution
     muse_wcs_create_default
     muse_wcs_project_tan
     muse_wcs_position_celestial
@@ -594,9 +604,40 @@ int main(int argc, char **argv)
     /* should both be about 0.2''/px */
     cpl_test_abs(xsc, 0.2/3600., klimitsINM[type][0]);
     cpl_test_abs(ysc, 0.2/3600., klimitsINM[type][1]);
+    /* test the added keywords */
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_RADIUS) > 0. &&
+             cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_RADIUS) <= 5.);
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_ACCURACY) > 0.);
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_FACCURACY) > 0. &&
+             cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_FACCURACY) <= 5.);
+
+    /* also test the iterative function */
+    if (type == MUSE_WCS_CENTROID_GAUSSIAN) {
+      /* run it with extra debug dumps once */
+      setenv("MUSE_DEBUG_WCS", "1", 1);
+    }
+    rc = muse_wcs_optimize_solution(wcsobj, -3., type, wcsref, 5., 5., 2, 3.);
+    muse_wcs_get_angles(wcsobj->wcs, &xang, &yang);
+    muse_wcs_get_scales(wcsobj->wcs, &xsc, &ysc);
+    cpl_msg_debug(__func__, "angles: %e,%e, scales: %e,%e", xang, yang, xsc, ysc);
+    cpl_test_lt(fabs(xang), klimitsINM[type][2]); /* almost no rotation */
+    cpl_test_lt(fabs(yang), klimitsINM[type][3]);
+    /* should both be about 0.2''/px */
+    cpl_test_abs(xsc, 0.2/3600., klimitsINM[type][0]);
+    cpl_test_abs(ysc, 0.2/3600., klimitsINM[type][1]);
+    /* test the added keywords */
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_DETSIGMA) >= 1.0 &&
+             cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_DETSIGMA) <= 3.0);
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_RADIUS) > 0. &&
+             cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_RADIUS) <= 5.);
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_ACCURACY) > 0.);
+    cpl_test(cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_FACCURACY) > 0. &&
+             cpl_propertylist_get_float(wcsobj->wcs, MUSE_HDR_WCS_FACCURACY) <= 5.);
+
     /* reinstate the original detected sources table */
-    cpl_table_delete(detected);
+    cpl_table_delete(wcsobj->detected);
     wcsobj->detected = saved;
+    unsetenv("MUSE_DEBUG_WCS");
   } /* for type */
   /* test some failure cases of muse_wcs_locate_sources() */
   cpl_errorstate state = cpl_errorstate_get();
@@ -679,6 +720,7 @@ int main(int argc, char **argv)
   cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_INPUT);
   cpl_errorstate_set(state);
   /* fake bad entries in the reference table to mess up object identification */
+  cpl_table *wcsref2 = cpl_table_duplicate(wcsref);
   cpl_table_fill_column_window(wcsref, "RA", 0, 100000, 10.);
   cpl_table_fill_column_window(wcsref, "DEC", 0, 100000, -10.);
   rc = muse_wcs_solve(wcsobj, wcsref, 5., 5., 2, 3.);
@@ -688,11 +730,54 @@ int main(int argc, char **argv)
   rc = muse_wcs_solve(wcsobj, wcsref, 5., 5., 2, 3.);
   cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_BAD_FILE_FORMAT);
   cpl_errorstate_set(state);
+  cpl_table_delete(wcsref);
   /* don't know how to simulate failure of cpl_wcs_platesol()... */
+  /* also test failures of muse_wcs_optimize_solution() */
+  state = cpl_errorstate_get();
+  rc = muse_wcs_optimize_solution(NULL, -3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_NULL_INPUT);
+  cpl_errorstate_set(state);
+  muse_datacube *cube99 = wcsobj->cube;
+  wcsobj->cube = NULL;
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_NULL_INPUT);
+  cpl_errorstate_set(state);
+  cube99 = wcsobj->cube = cube99;
+  char *astname = cpl_strdup(cpl_array_get_string(wcsobj->cube->recnames, 1));
+  cpl_array_set_string(wcsobj->cube->recnames, 1, "not_astrometric");
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_DATA_NOT_FOUND);
+  cpl_errorstate_set(state);
+  cpl_array_set_string(wcsobj->cube->recnames, 1, astname);
+  cpl_free(astname);
+  rc = muse_wcs_optimize_solution(wcsobj, 3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_INPUT);
+  cpl_errorstate_set(state);
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_BOX + 1, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_INPUT);
+  cpl_errorstate_set(state);
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_GAUSSIAN, NULL, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_INPUT);
+  cpl_errorstate_set(state);
+  cpl_table_name_column(wcsref2, "RA", "2_RA");
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_BAD_FILE_FORMAT);
+  cpl_errorstate_set(state);
+  cpl_table_name_column(wcsref2, "2_RA", "RA");
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, -5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_INPUT);
+  cpl_errorstate_set(state);
+  rc = muse_wcs_optimize_solution(wcsobj, -3., MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., -5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_INPUT);
+  cpl_errorstate_set(state);
+  rc = muse_wcs_optimize_solution(wcsobj, -0.1, MUSE_WCS_CENTROID_GAUSSIAN, wcsref2, 5., 5., 2, 3.);
+  cpl_test(!cpl_errorstate_is_equal(state) && rc == CPL_ERROR_ILLEGAL_OUTPUT);
+  cpl_errorstate_set(state);
+  /* don't know how to make the final muse_wcs_solve() call in that function fail... */
   /* clean up this part */
   muse_pixtable_delete(pt2);
   muse_pixtable_delete(ptin);
-  cpl_table_delete(wcsref);
+  cpl_table_delete(wcsref2);
   state = cpl_errorstate_get();
   muse_wcs_object_delete(wcsobj);
   cpl_test(cpl_errorstate_is_equal(state));
