@@ -69,8 +69,9 @@ int main(int argc, char **argv)
 {
   const char *idstring = "muse_cube_filter";
   cpl_init(CPL_INIT_DEFAULT);
-  cpl_msg_set_level(CPL_MSG_DEBUG);
   cpl_msg_set_time_on();
+  muse_processing_recipeinfo(NULL);
+  cpl_msg_set_level(CPL_MSG_DEBUG);
   cpl_msg_set_component_on();
   cpl_errorstate state = cpl_errorstate_get();
 
@@ -137,8 +138,10 @@ int main(int argc, char **argv)
     } while (cpl_errorstate_is_equal(es));
     cpl_errorstate_set(es);
   } /* if no filters given */
+#if 0
   cpl_array_dump(filters, 0, 10000, stdout);
   fflush(stdout);
+#endif
 
   cpl_msg_info(idstring, "Loading cube \"%s\"", iname);
   muse_datacube *cube = muse_datacube_load(iname);
@@ -184,8 +187,10 @@ int main(int argc, char **argv)
   cpl_array_delete(filters);
   muse_datacube_delete(cube);
 
-  cpl_array_dump(names, 0, 10, stdout);
+#if 0
+  cpl_array_dump(names, 0, n, stdout);
   fflush(stdout);
+#endif
 
   /* extended format: append the new images to the original cube file */
   n = muse_imagelist_get_size(images);
